@@ -9,5 +9,8 @@ var classviennacl_1_1matrix__range =
     [ "value_type", "classviennacl_1_1matrix__range.html#ad436ae3cbfcb2ab134f4b8727828259e", null ],
     [ "matrix_range", "classviennacl_1_1matrix__range.html#a6178a1a8edf196ce5032738da4877b25", null ],
     [ "matrix_range", "classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2", null ],
-    [ "matrix_range", "classviennacl_1_1matrix__range.html#a3a6b55a656dc7ad97e7d2ad9aa625f18", null ]
+    [ "matrix_range", "classviennacl_1_1matrix__range.html#a3a6b55a656dc7ad97e7d2ad9aa625f18", null ],
+    [ "operator=", "classviennacl_1_1matrix__range.html#a1d46c33083bf7c74898c69801c25e8cb", null ],
+    [ "operator=", "classviennacl_1_1matrix__range.html#a2bd2b1d5a66cb256ae3ebcefcdc10183", null ],
+    [ "operator=", "classviennacl_1_1matrix__range.html#ab15ae025d7115f09d1c9687c24474321", null ]
 ];
\ No newline at end of file
