@@ -1,7 +1,8 @@
 var cuda_2iterative__operations_8hpp =
 [
     [ "pipelined_bicgstab_coo_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a86390fe48798192c7390e39d92f97520", null ],
-    [ "pipelined_bicgstab_csr_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a15bebdac73a80ac68a4f71f2e468ff03", null ],
+    [ "pipelined_bicgstab_csr_vec_mul_adaptive_kernel", "cuda_2iterative__operations_8hpp.html#a5ecd142151311526e082d97f414d4918", null ],
+    [ "pipelined_bicgstab_csr_vec_mul_blocked_kernel", "cuda_2iterative__operations_8hpp.html#a20569b26491132913273a1d57034bd3d", null ],
     [ "pipelined_bicgstab_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#ae0d62b462379fe42e81f900a321eb297", null ],
     [ "pipelined_bicgstab_hyb_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a6c9f7768d5c2e10330ab997498f41453", null ],
     [ "pipelined_bicgstab_prod", "cuda_2iterative__operations_8hpp.html#ae0d31ed131e01b317f245b01d1b860a0", null ],
@@ -9,13 +10,14 @@ var cuda_2iterative__operations_8hpp =
     [ "pipelined_bicgstab_prod", "cuda_2iterative__operations_8hpp.html#a65d8cfcf1cee766429508e117eada71d", null ],
     [ "pipelined_bicgstab_prod", "cuda_2iterative__operations_8hpp.html#a5c3058c69102ff27e3c0cea62c402c2a", null ],
     [ "pipelined_bicgstab_prod", "cuda_2iterative__operations_8hpp.html#a7f982f594432ad424f4cb6e774b8fa19", null ],
-    [ "pipelined_bicgstab_sliced_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a8cc43bc91378501e1dd1dd755d71642a", null ],
+    [ "pipelined_bicgstab_sliced_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#afc885e66ea0c304b817b95ed24f46fa1", null ],
     [ "pipelined_bicgstab_update_s", "cuda_2iterative__operations_8hpp.html#a494ed2f09e16bd3c526e11614760ad1d", null ],
     [ "pipelined_bicgstab_update_s_kernel", "cuda_2iterative__operations_8hpp.html#af050e6eba3a68ce30af78180bf8fda4a", null ],
     [ "pipelined_bicgstab_vector_kernel", "cuda_2iterative__operations_8hpp.html#a1e20ba11b18ef4d72f83d8e607f87b31", null ],
     [ "pipelined_bicgstab_vector_update", "cuda_2iterative__operations_8hpp.html#ab06346505de4a3b8bf2a1ff523622903", null ],
     [ "pipelined_cg_coo_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#af13d83b719540f28d9ec7a3c1feece02", null ],
-    [ "pipelined_cg_csr_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a75736f7687babaabe269f432b681503c", null ],
+    [ "pipelined_cg_csr_vec_mul_adaptive_kernel", "cuda_2iterative__operations_8hpp.html#af4c3d23bea4184ca7889936e9e305547", null ],
+    [ "pipelined_cg_csr_vec_mul_blocked_kernel", "cuda_2iterative__operations_8hpp.html#af2c0a10d54938e966767bbad07f60771", null ],
     [ "pipelined_cg_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0", null ],
     [ "pipelined_cg_hyb_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#ad6e3793be60ca5210a56f8d2c8fccd7f", null ],
     [ "pipelined_cg_prod", "cuda_2iterative__operations_8hpp.html#a69f7e032f6d9f6cbd97fd7516940af97", null ],
@@ -23,7 +25,7 @@ var cuda_2iterative__operations_8hpp =
     [ "pipelined_cg_prod", "cuda_2iterative__operations_8hpp.html#a085a61ef1f2fceeb591d6d7edd0bcb4e", null ],
     [ "pipelined_cg_prod", "cuda_2iterative__operations_8hpp.html#a4cbb020d4820cce3a4db383efa611ecb", null ],
     [ "pipelined_cg_prod", "cuda_2iterative__operations_8hpp.html#aa83c7101b05e9185f660f930ca9efb2c", null ],
-    [ "pipelined_cg_sliced_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#ae6abf596053acd24e2eeca31127c8f65", null ],
+    [ "pipelined_cg_sliced_ell_vec_mul_kernel", "cuda_2iterative__operations_8hpp.html#a256d2205f098170fdbc0d824a81c75f1", null ],
     [ "pipelined_cg_vector_kernel", "cuda_2iterative__operations_8hpp.html#aef20cd32ec9f7c6299573e19318f976a", null ],
     [ "pipelined_cg_vector_update", "cuda_2iterative__operations_8hpp.html#aedeca519719a2fcd21198220cb2f05f2", null ],
     [ "pipelined_gmres_gram_schmidt_stage1", "cuda_2iterative__operations_8hpp.html#af8a1bdfc669f947e93987f66d3090172", null ],
@@ -32,7 +34,7 @@ var cuda_2iterative__operations_8hpp =
     [ "pipelined_gmres_gram_schmidt_stage2_kernel", "cuda_2iterative__operations_8hpp.html#acaaa759ba8f6ed9ce08b8e2d7eb17eac", null ],
     [ "pipelined_gmres_normalize_vk", "cuda_2iterative__operations_8hpp.html#a2210bf2052e1542a16afd8e7bb36c8aa", null ],
     [ "pipelined_gmres_normalize_vk_kernel", "cuda_2iterative__operations_8hpp.html#aa29b735545a2a7ea98658d36a6e86284", null ],
-    [ "pipelined_gmres_prod", "cuda_2iterative__operations_8hpp.html#a7f57426fbc4a00904dc1719dc0ce2951", null ],
+    [ "pipelined_gmres_prod", "cuda_2iterative__operations_8hpp.html#a9ab90f6c8f9931ad766cc757e3d52f6b", null ],
     [ "pipelined_gmres_prod", "cuda_2iterative__operations_8hpp.html#a4743561c3e55917bc8d081ce1cd0f5d4", null ],
     [ "pipelined_gmres_prod", "cuda_2iterative__operations_8hpp.html#a569acbd9c766c05321bd1336f12fa326", null ],
     [ "pipelined_gmres_prod", "cuda_2iterative__operations_8hpp.html#a2e9e7aa9bcc654c9d8ed46fe9866fa59", null ],
