@@ -10,13 +10,16 @@ var host__based_2vector__operations_8hpp =
     [ "av", "host__based_2vector__operations_8hpp.html#a47e4fa3cd849b7beab25f195633a38ad", null ],
     [ "avbv", "host__based_2vector__operations_8hpp.html#a7634739b4c75267d38297dfcb19fad63", null ],
     [ "avbv_v", "host__based_2vector__operations_8hpp.html#a9e173eb4a7b8b63e7bddb53074d764ec", null ],
+    [ "convert", "host__based_2vector__operations_8hpp.html#a4741c01014517323f006507e09de2143", null ],
     [ "element_op", "host__based_2vector__operations_8hpp.html#affd4a240838f3d33cfd0f37c4085d558", null ],
     [ "element_op", "host__based_2vector__operations_8hpp.html#ade366c76e4b0db7585c51d890c88051d", null ],
+    [ "exclusive_scan", "host__based_2vector__operations_8hpp.html#a43942d99b5d1ce74238e073aac275eb7", null ],
     [ "flip_sign", "host__based_2vector__operations_8hpp.html#abd382e4bde97fb842b7b52b2b4d36379", null ],
     [ "flip_sign", "host__based_2vector__operations_8hpp.html#ae3225408ae3e81b004fab27aeb6a9482", null ],
     [ "flip_sign", "host__based_2vector__operations_8hpp.html#a9d0a372a4ffd0c6347ecff6046ca4dec", null ],
     [ "flip_sign", "host__based_2vector__operations_8hpp.html#a7446f9329fa901df46a4f487a43601ca", null ],
     [ "flip_sign", "host__based_2vector__operations_8hpp.html#a306a6b1400991db3671a1511fa8f6f40", null ],
+    [ "inclusive_scan", "host__based_2vector__operations_8hpp.html#ace2ac2eae0198df73a1960c45cbbb7c7", null ],
     [ "index_norm_inf", "host__based_2vector__operations_8hpp.html#aa9936ab7a49e99f2935f7dc33b95c976", null ],
     [ "inner_prod_impl", "host__based_2vector__operations_8hpp.html#ad78c38a7e4a3ae75bc2e149b28854eaa", null ],
     [ "inner_prod_impl", "host__based_2vector__operations_8hpp.html#abd70c99f406759e0f1ae2ffc6c9e8fed", null ],
@@ -26,6 +29,8 @@ var host__based_2vector__operations_8hpp =
     [ "norm_2_impl", "host__based_2vector__operations_8hpp.html#a84f017afe97029f92d48c968774f245b", null ],
     [ "norm_inf_impl", "host__based_2vector__operations_8hpp.html#a64a65b7cd5c499e1a2e12ae921ec1ca2", null ],
     [ "plane_rotation", "host__based_2vector__operations_8hpp.html#a7038bea435ceada730575e20bbcd56a6", null ],
+    [ "sum_impl", "host__based_2vector__operations_8hpp.html#ae2bfa1890191051eeca95db258511533", null ],
     [ "vector_assign", "host__based_2vector__operations_8hpp.html#a38954effaaf57109159e51a31293a6c1", null ],
+    [ "vector_scan_impl", "host__based_2vector__operations_8hpp.html#a90e2cace173fdf7396eae21660fdbc22", null ],
     [ "vector_swap", "host__based_2vector__operations_8hpp.html#ac765726382000520401dc9d70483dabb", null ]
 ];
\ No newline at end of file
