@@ -3,6 +3,8 @@ var linalg_2opencl_2kernels_2vector_8hpp =
     [ "vector", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
     [ "vector_multi_inner_prod", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ],
     [ "vector_element", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html", null ],
+    [ "vector_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__convert.html", null ],
     [ "VIENNACL_ADD_BINARY", "linalg_2opencl_2kernels_2vector_8hpp.html#a67f9921aa086b1cab31a7ba49c722f84", null ],
-    [ "VIENNACL_ADD_UNARY", "linalg_2opencl_2kernels_2vector_8hpp.html#ae7e49843c99a526b2605212454475394", null ]
+    [ "VIENNACL_ADD_UNARY", "linalg_2opencl_2kernels_2vector_8hpp.html#ae7e49843c99a526b2605212454475394", null ],
+    [ "generate_vector_convert", "linalg_2opencl_2kernels_2vector_8hpp.html#ab3975c352a410e67ae3b93c147dc59a3", null ]
 ];
\ No newline at end of file
