@@ -1,6 +1,5 @@
 var matrix__operations__col_8hpp =
 [
-    [ "VIENNACL_SECTION_SIZE", "matrix__operations__col_8hpp.html#a896e84eed510eabefb25c2dc08bffef4", null ],
     [ "am_col_kernel", "matrix__operations__col_8hpp.html#a91b71139db24f7f9ba9c5b71d52074f2", null ],
     [ "am_col_kernel", "matrix__operations__col_8hpp.html#ad3013060178ead4df58b45267f40d4c0", null ],
     [ "ambm_col_kernel", "matrix__operations__col_8hpp.html#a8f4e7ebf412327b90fdfe1cccea00535", null ],
@@ -14,13 +13,13 @@ var matrix__operations__col_8hpp =
     [ "bidiag_pack_column_major_kernel", "matrix__operations__col_8hpp.html#a5a5428207a302cf214abff0bb33b516b", null ],
     [ "bidiag_pack_row_major_kernel", "matrix__operations__col_8hpp.html#a39ebb0f5f28d79b723dbaac8a64273a9", null ],
     [ "col_reduce_lcl_array", "matrix__operations__col_8hpp.html#a8cdfd433b14d36f5b2ba2467e3770e9c", null ],
+    [ "convert_col_kernel", "matrix__operations__col_8hpp.html#a155b66551a7b68c4768d015d9d70c7f7", null ],
     [ "copy_col_column_major_kernel", "matrix__operations__col_8hpp.html#a915463c1be02a593266096a6ea6f18d1", null ],
     [ "copy_col_row_major_kernel", "matrix__operations__col_8hpp.html#a78741b4ca602471b1009ad8919ebb379", null ],
     [ "copy_row_column_major_kernel", "matrix__operations__col_8hpp.html#a6c57d2fd37a41d5b2984076b949ba2ea", null ],
     [ "copy_row_row_major_kernel", "matrix__operations__col_8hpp.html#a7e4d5ed0c0b4e2e2511c11c8e71cf794", null ],
     [ "element_op_col_kernel", "matrix__operations__col_8hpp.html#ad186550fd426ada7b82e6b7e6e6d0592", null ],
     [ "element_op_int_col_kernel", "matrix__operations__col_8hpp.html#a87a97b430df75bec5177d7e73e8af682", null ],
-    [ "exclusive_scan_kernel_1", "matrix__operations__col_8hpp.html#a13b2a55ca7df73985ab6ab1d7cf4976e", null ],
     [ "givens_next_column_major_kernel", "matrix__operations__col_8hpp.html#a1d46df86192612762697a3d54d4edc6b", null ],
     [ "givens_next_row_major_kernel", "matrix__operations__col_8hpp.html#a9a148ebc1c5e9509474e08692c67bec1", null ],
     [ "house_update_A_left_column_major_kernel", "matrix__operations__col_8hpp.html#adbb7c5e437951f0b9062811120ad4339", null ],
@@ -29,7 +28,6 @@ var matrix__operations__col_8hpp =
     [ "house_update_A_right_row_major_kernel", "matrix__operations__col_8hpp.html#a0549ca86fcc12b0ade31a71884c15a5b", null ],
     [ "house_update_QL_column_major_kernel", "matrix__operations__col_8hpp.html#ae6c6dd3942c0d897ff5df75cdbc5bfb6", null ],
     [ "house_update_QL_row_major_kernel", "matrix__operations__col_8hpp.html#a71f2ca5126aa0a9c745cb5575fdef3f6", null ],
-    [ "inclusive_scan_kernel_1", "matrix__operations__col_8hpp.html#ae5ee136bf581cc57aba1e01e989378fb", null ],
     [ "matrix_col_assign_kernel", "matrix__operations__col_8hpp.html#a73702d7116c0b7bbfa9553052719f928", null ],
     [ "matrix_col_diagonal_assign_kernel", "matrix__operations__col_8hpp.html#a24d7b938c62c7683a4350287216010bd", null ],
     [ "matrix_col_element_abs_kernel", "matrix__operations__col_8hpp.html#a8b9865449bd2d824e280400cd13f3802", null ],
@@ -51,9 +49,6 @@ var matrix__operations__col_8hpp =
     [ "matrix_col_element_tanh_kernel", "matrix__operations__col_8hpp.html#a3988d6581519c75da05cbb56f6d90bc3", null ],
     [ "scaled_rank1_update_col_kernel", "matrix__operations__col_8hpp.html#a58b2c423ab9e3d062e5ac177b38ee37e", null ],
     [ "scaled_rank1_update_col_kernel", "matrix__operations__col_8hpp.html#a1eda64ee9b4614785aaea3b6ea4783cb", null ],
-    [ "scan_kernel_2", "matrix__operations__col_8hpp.html#aa73250643a44654944ed433511e7a780", null ],
-    [ "scan_kernel_3", "matrix__operations__col_8hpp.html#ad4a98a06b04ed2cfeab79551ec045e9e", null ],
-    [ "scan_kernel_4", "matrix__operations__col_8hpp.html#aec60885b11f195e5bb71fbb926c71dc4", null ],
     [ "trans_vec_mul_col_kernel", "matrix__operations__col_8hpp.html#ada17736bf8769a2151354ce39ef64936", null ],
     [ "vec_mul_col_kernel", "matrix__operations__col_8hpp.html#a654f609cd7848b45b38939e003fbf5af", null ]
 ];
\ No newline at end of file
