@@ -1,60 +1,5 @@
 var NAVTREEINDEX10 =
 {
-"custom-kernels_8cpp_source.html":[7,0,0,1,8],
-"cuthill__mckee_8hpp.html":[7,0,3,6,1],
-"cuthill__mckee_8hpp.html#a032f691cd245d13b51b951f8a10825f3":[7,0,3,6,1,11],
-"cuthill__mckee_8hpp.html#a0368076ca5c74ec328c48924db5feeb8":[7,0,3,6,1,7],
-"cuthill__mckee_8hpp.html#a1196927ad66b47cf5826181369c472d0":[7,0,3,6,1,9],
-"cuthill__mckee_8hpp.html#a46b125c9e12a72a453f0ff2885d0eafe":[7,0,3,6,1,3],
-"cuthill__mckee_8hpp.html#a633f2200739984a3b78ac3e02496da03":[7,0,3,6,1,5],
-"cuthill__mckee_8hpp.html#a91de3dbbe3f9a663fdbee15e1945fde2":[7,0,3,6,1,2],
-"cuthill__mckee_8hpp.html#aeeba1f9a93970b70dbdf8eced30e167d":[7,0,3,6,1,6],
-"cuthill__mckee_8hpp.html#af22338e452cee008bee5e38070ddc611":[7,0,3,6,1,10],
-"cuthill__mckee_8hpp.html#af4e69f290073504270f69f75bece0924":[7,0,3,6,1,4],
-"cuthill__mckee_8hpp.html#afc45d444ac8e66896ee5ba2b186a8510":[7,0,3,6,1,8],
-"cuthill__mckee_8hpp_source.html":[7,0,3,6,1],
-"cypress_8hpp.html":[7,0,3,2,0,0,2,0,0,1],
-"cypress_8hpp.html#a0465b4268c249dfaa94b987df68e0203":[7,0,3,2,0,0,2,0,0,1,11],
-"cypress_8hpp.html#a04b170219e447a120fb23c87fae66869":[7,0,3,2,0,0,2,0,0,1,10],
-"cypress_8hpp.html#a127308a8610f95cbc064d6cac6ca98a9":[7,0,3,2,0,0,2,0,0,1,1],
-"cypress_8hpp.html#a1a69df21383cd6fdcdbd391bc1146f6d":[7,0,3,2,0,0,2,0,0,1,8],
-"cypress_8hpp.html#a23ebc62288af5363da814000605f79e7":[7,0,3,2,0,0,2,0,0,1,9],
-"cypress_8hpp.html#a23fe3d74720124f6ef339cd196d86831":[7,0,3,2,0,0,2,0,0,1,0],
-"cypress_8hpp.html#a27db422105c8d9650b1248f09a972248":[7,0,3,2,0,0,2,0,0,1,6],
-"cypress_8hpp.html#a28f48231f00081a98ddcd7cd8135910c":[7,0,3,2,0,0,2,0,0,1,3],
-"cypress_8hpp.html#a40a59de4f3f2ca3c52708296c0541573":[7,0,3,2,0,0,2,0,0,1,13],
-"cypress_8hpp.html#a8638ef1d9e292eb6295ab2604dbaa4ce":[7,0,3,2,0,0,2,0,0,1,12],
-"cypress_8hpp.html#ab5cf26400e2a97ef5af2a86509451d44":[7,0,3,2,0,0,2,0,0,1,5],
-"cypress_8hpp.html#ab787739a0e379046b0859f1d1ba046fd":[7,0,3,2,0,0,2,0,0,1,7],
-"cypress_8hpp.html#acd226a7692103ffd46b9944a9737581e":[7,0,3,2,0,0,2,0,0,1,4],
-"cypress_8hpp.html#ae53b5bdcfa19555dc45f00ca47f356f8":[7,0,3,2,0,0,2,0,0,1,2],
-"cypress_8hpp_source.html":[7,0,3,2,0,0,2,0,0,1],
-"dense__blas_8cpp.html":[7,0,0,0,1],
-"dense__blas_8cpp.html#a0c464e202ab39eece213320f33750b8b":[7,0,0,0,1,0],
-"dense__blas_8cpp.html#a394a1b0572531e380bc94ec20cd7a20c":[7,0,0,0,1,2],
-"dense__blas_8cpp.html#a7044d46a24870e1508e14dc2b6c3c104":[7,0,0,0,1,3],
-"dense__blas_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,1,4],
-"dense__blas_8cpp.html#af6bb6f04705830fb7e059fe0572778d6":[7,0,0,0,1,1],
-"dense__blas_8cpp_source.html":[7,0,0,0,1],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html":[7,0,3,4,1,1,0],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a049a115f9821da18cc960a5170bd2692":[7,0,3,4,1,1,0,3],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a4b0688e2a510e3fdc62fab34aedce77b":[7,0,3,4,1,1,0,1],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a82198b841ca247fd74b6a8b39242d708":[7,0,3,4,1,1,0,2],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#ada59d9072c648b1dde7f09c15d6b20de":[7,0,3,4,1,1,0,0],
-"detail_2bisect_2bisect__kernel__calls_8hpp_source.html":[7,0,3,4,1,1,0],
-"detail_2spai_2qr_8hpp.html":[7,0,3,4,1,3,3],
-"detail_2spai_2qr_8hpp.html#a08cfda20cf63c245a5c22034875743da":[7,0,3,4,1,3,3,0],
-"detail_2spai_2qr_8hpp.html#a0f734abea08b6732fb5a6d3d50f36319":[7,0,3,4,1,3,3,6],
-"detail_2spai_2qr_8hpp.html#a1bcb9bff13f114739f5f7d70d5b38223":[7,0,3,4,1,3,3,1],
-"detail_2spai_2qr_8hpp.html#a34b989396d25d3ec653ea0aa1e620f55":[7,0,3,4,1,3,3,11],
-"detail_2spai_2qr_8hpp.html#a65295176395fdf1c526d3880f3d76b53":[7,0,3,4,1,3,3,18],
-"detail_2spai_2qr_8hpp.html#a6e707b637111b93ec04a6149aa72eac4":[7,0,3,4,1,3,3,16],
-"detail_2spai_2qr_8hpp.html#a7434114c0e1f546e32b4bc2a81a35ad1":[7,0,3,4,1,3,3,14],
-"detail_2spai_2qr_8hpp.html#a7eeb3f2f51183bed7e6d0a1aeefc87bc":[7,0,3,4,1,3,3,8],
-"detail_2spai_2qr_8hpp.html#a9a76ae3dcfedb876ec9f2db3155b81a7":[7,0,3,4,1,3,3,4],
-"detail_2spai_2qr_8hpp.html#a9c9928b400d93d677b626c5ea9e51819":[7,0,3,4,1,3,3,5],
-"detail_2spai_2qr_8hpp.html#aa237a50ec1e8dd5e279a0fb02ff0bf8f":[7,0,3,4,1,3,3,13],
-"detail_2spai_2qr_8hpp.html#aa47df1186969f6872fe0dcaf83d4982b":[7,0,3,4,1,3,3,12],
 "detail_2spai_2qr_8hpp.html#aa50a771c3604ad3913905871d54176f4":[7,0,3,4,1,3,3,3],
 "detail_2spai_2qr_8hpp.html#ab3b64ba7bb53a1526cc852daf0d4d53e":[7,0,3,4,1,3,3,2],
 "detail_2spai_2qr_8hpp.html#abbff207e6f84bc89822c0eab0aea0fe7":[7,0,3,4,1,3,3,15],
@@ -107,13 +52,14 @@ var NAVTREEINDEX10 =
 "device__specific_2execute_8hpp.html#a0e0576421dc6e48555abd251d0a83ae0":[7,0,3,2,2,0],
 "device__specific_2execute_8hpp_source.html":[7,0,3,2,2],
 "device__specific_2forwards_8h.html":[7,0,3,2,4],
+"device__specific_2forwards_8h.html#a08bd08c6dc86b78e78749891e8832fe4":[7,0,3,2,4,16],
 "device__specific_2forwards_8h.html#a4ae1b6692dfe648094c52c14f0e81d45":[7,0,3,2,4,11],
 "device__specific_2forwards_8h.html#a5927db4220a325127326f3391ddf3321":[7,0,3,2,4,10],
-"device__specific_2forwards_8h.html#a5a4282524aeeafba4d9c5e44397403e7":[7,0,3,2,4,21],
-"device__specific_2forwards_8h.html#a70f9b436519b02537064504f3a327470":[7,0,3,2,4,23],
-"device__specific_2forwards_8h.html#a7935d6fe2cb68ce032c9a177ed7f1d41":[7,0,3,2,4,22],
-"device__specific_2forwards_8h.html#a810fd16fbb883a4987ff0cf720d47037":[7,0,3,2,4,16],
-"device__specific_2forwards_8h.html#a89c2dbe54841c653951eaa6a248c7526":[7,0,3,2,4,19],
+"device__specific_2forwards_8h.html#a5a4282524aeeafba4d9c5e44397403e7":[7,0,3,2,4,22],
+"device__specific_2forwards_8h.html#a70f9b436519b02537064504f3a327470":[7,0,3,2,4,24],
+"device__specific_2forwards_8h.html#a7935d6fe2cb68ce032c9a177ed7f1d41":[7,0,3,2,4,23],
+"device__specific_2forwards_8h.html#a810fd16fbb883a4987ff0cf720d47037":[7,0,3,2,4,17],
+"device__specific_2forwards_8h.html#a89c2dbe54841c653951eaa6a248c7526":[7,0,3,2,4,20],
 "device__specific_2forwards_8h.html#aa451f851b492f6422bfdd71f51fdc1fb":[7,0,3,2,4,7],
 "device__specific_2forwards_8h.html#aaa1f965282523dc44221b5ee4a99d41b":[7,0,3,2,4,8],
 "device__specific_2forwards_8h.html#ab912aba0d144f286022bb3af5d5f8f77":[7,0,3,2,4,15],
@@ -121,7 +67,7 @@ var NAVTREEINDEX10 =
 "device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9":[7,0,3,2,4,12],
 "device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9a5bac3e336ba87e7a3311dee3d2129db5":[7,0,3,2,4,12,1],
 "device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9a763b24a54e9bdb083926bc27e90ba0d6":[7,0,3,2,4,12,0],
-"device__specific_2forwards_8h.html#acf5956ffbc42d6804ba7f9c2376ddc75":[7,0,3,2,4,20],
+"device__specific_2forwards_8h.html#acf5956ffbc42d6804ba7f9c2376ddc75":[7,0,3,2,4,21],
 "device__specific_2forwards_8h.html#ad55da4cae5e36eebf058630a18c9994a":[7,0,3,2,4,13],
 "device__specific_2forwards_8h.html#ad55da4cae5e36eebf058630a18c9994aa02873b19330807931f0cdbc7eaa39367":[7,0,3,2,4,13,10],
 "device__specific_2forwards_8h.html#ad55da4cae5e36eebf058630a18c9994aa1c0b92aa1d8faca54338c8ad93f81de7":[7,0,3,2,4,13,5],
@@ -138,8 +84,8 @@ var NAVTREEINDEX10 =
 "device__specific_2forwards_8h.html#ae3c2256f348f5311933d23d2f699fa12a1a3b79f66ece749edf7fc6d8586d5f1a":[7,0,3,2,4,14,2],
 "device__specific_2forwards_8h.html#ae3c2256f348f5311933d23d2f699fa12a6f3d3028017d020e2fc0e4157449caff":[7,0,3,2,4,14,1],
 "device__specific_2forwards_8h.html#ae3c2256f348f5311933d23d2f699fa12afbf0ae324c55a1c703b3cc3e425a0bd6":[7,0,3,2,4,14,0],
-"device__specific_2forwards_8h.html#ae9b56899cd3fc4fb4f0ab83ee174b26b":[7,0,3,2,4,18],
-"device__specific_2forwards_8h.html#af46ac461e9e315b07018aef4110de10b":[7,0,3,2,4,17],
+"device__specific_2forwards_8h.html#ae9b56899cd3fc4fb4f0ab83ee174b26b":[7,0,3,2,4,19],
+"device__specific_2forwards_8h.html#af46ac461e9e315b07018aef4110de10b":[7,0,3,2,4,18],
 "device__specific_2forwards_8h_source.html":[7,0,3,2,4],
 "device__specific_2templates_2utils_8hpp.html":[7,0,3,2,1,5],
 "device__specific_2templates_2utils_8hpp.html#a0caa2acde930200ff31a87e7fbf0c9a1":[7,0,3,2,1,5,3],
@@ -180,74 +126,128 @@ var NAVTREEINDEX10 =
 "device__utils_8hpp.html#ac19deb058c8b979eba1faba219542c35af25058db0b8bd4549bfc505a1fabd65c":[7,0,3,7,4,2,7],
 "device__utils_8hpp.html#ac19deb058c8b979eba1faba219542c35af9a1d1ba7d8da2e2d3156ca47b0313a2":[7,0,3,7,4,2,1],
 "device__utils_8hpp_source.html":[7,0,3,7,4],
-"dir_16664ee5917227688a793c46bff13f10.html":[7,0,3,1],
-"dir_19b91ce24010a277ae42e0f12bdd020d.html":[7,0,3,4,3,0],
-"dir_225062f072d8eb572e25b876c44903f8.html":[7,0,3,0],
-"dir_2753ed8074493aeff3e0515eb0266828.html":[7,0,3,4,1],
-"dir_27edd4ef761976637f0a6ff19cff4c00.html":[7,0,3,4,1,2],
-"dir_28beffbf6e9a4aae9ebfd9c70ae78dbb.html":[7,0,3,2,0,0,1],
-"dir_28d0cd2c2b69cc52f4592b0100abbb19.html":[7,0,3,2,0,0,2,0,2],
-"dir_2aede027c3fab12899418e3db60d7e7a.html":[7,0,3,4,0],
-"dir_3f34dde6f45e42123944fdf74c951721.html":[7,0,3,2,0],
-"dir_46cfbf617d85ee2b7d727c96b372dc67.html":[7,0,3,2,0,0,2,0,1],
-"dir_49d9f40cb486c21f519277654eaf1706.html":[7,0,3,2],
-"dir_4cce297acab7995b556697564a5c781a.html":[7,0,2],
-"dir_54216ae2e4dd664125f44b7fd28e4307.html":[7,0,3,9],
-"dir_5d0e0c49da9183844fcfe7c46dce8078.html":[7,0,1],
-"dir_63cde087767c4ed65c7901ffc6e293fe.html":[7,0,3,4],
-"dir_64c1c02bcadf9f69b9adb149c0a5035c.html":[7,0,3,2,0,0,2],
-"dir_69e45189a60a9e7cdae73056ab62ba64.html":[7,0,1,0],
-"dir_717f42b2bc9c32450292c49ab28b084d.html":[7,0,3,3],
-"dir_88cf2948f5fd612ee5751a9df4dcf539.html":[7,0,3,10],
-"dir_891862c9d10548f0b71e7a20afa28180.html":[7,0,3,2,0,0,2,0,0],
-"dir_8d65d6aa9e8b523925f2b9aaa58554fe.html":[7,0,3,8],
-"dir_8d734bf48796b8afc2ea3e50ddaea273.html":[7,0,3,4,2],
-"dir_8e9f3cc091f3e773a2961f7e1b2269a2.html":[7,0,3,6],
-"dir_8eb26a60ce7e4e74227e98fac5455a0e.html":[7,0,3,2,0,0,0],
-"dir_952080306f114f51a8f2d73e253ffb05.html":[7,0,3,2,0,0,2,1,2],
-"dir_95ddc301de7dff4151ad233d69616cc0.html":[7,0,2,0],
-"dir_9d6102a0bd98effb16f0ae15f80f4955.html":[7,0,3,2,0,0,2,0],
-"dir_9d83cdcad950ebf3600600fb35f63223.html":[7,0,3,7],
-"dir_9df590563da805a074404567c6e27abf.html":[7,0,3,4,3],
-"dir_a5d754652166e9a81bc9a52ffaf77760.html":[7,0,0,1],
-"dir_a78feceb34e860582b3d668a1009a0c5.html":[7,0,3,4,1,0],
-"dir_a905ce029440da2b05eea32d8557e825.html":[7,0,3,2,1],
-"dir_aa995bfae49b010b59767b6c6eeaeea5.html":[7,0,1,1],
-"dir_aa9c51eb28287244843c1d8e47ca0d4b.html":[7,0,3,2,0,0,2,1],
-"dir_ac15a598d0f4a939ccff6b1a44621590.html":[7,0,3,2,0,0],
-"dir_b76e1ea04152a1f4ad74f59634c8ce42.html":[7,0,3,2,0,0,2,1,0],
-"dir_c82e3d11dd171600f4a6e0cab1ec1e0d.html":[7,0,3],
-"dir_cefc9203477f333ab105ea8579c62693.html":[7,0,3,5],
-"dir_cf1005d941559b8247e0b371f7ec5325.html":[7,0,3,2,0,0,2,1,1],
-"dir_d19492564bd1307bd18c84298ee04469.html":[7,0,3,4,1,3],
-"dir_d8545eca993c5d9c7906a844d16124ca.html":[7,0,0,0],
-"dir_e3caf1d7a9bf57697faf63bc7e466f4c.html":[7,0,3,2,0,0,2,0,3],
-"dir_e6cbf65cd48c4de0cbf6207c238fcdc2.html":[7,0,0],
-"dir_f2f353a0caae60a604684eba008d62d6.html":[7,0,3,4,1,1],
-"dir_fd2283f1c867d7bf85da4bd3c6348507.html":[7,0,3,2,0,0,2,1,3],
-"direct__solve_8cpp.html":[7,0,0,0,2],
-"direct__solve_8cpp.html#a33980228e5f215fd71462379cd1211b9":[7,0,0,0,2,2],
-"direct__solve_8cpp.html#a76c117307d545decb2480596430b8ed0":[7,0,0,0,2,5],
-"direct__solve_8cpp.html#aa65d2e04f3d59333c77d100f1a63c629":[7,0,0,0,2,4],
-"direct__solve_8cpp.html#aabc64c16d2e1b298f71fb50d4ce3415b":[7,0,0,0,2,1],
-"direct__solve_8cpp.html#ad8c59b30c7fc4da98b394ebe66097547":[7,0,0,0,2,6],
-"direct__solve_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18":[7,0,0,0,2,0],
-"direct__solve_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,2,3],
-"direct__solve_8cpp_source.html":[7,0,0,0,2],
-"direct__solve_8hpp.html":[7,0,3,4,10],
-"direct__solve_8hpp.html#a09afb0da48b9fe60af6bd01f59e31f50":[7,0,3,4,10,5],
-"direct__solve_8hpp.html#a170ab446494c96b18e351a8b26d82166":[7,0,3,4,10,15],
-"direct__solve_8hpp.html#a1c5dfe2ca91ca582638c39016c0a208e":[7,0,3,4,10,21],
-"direct__solve_8hpp.html#a2b533943999da7966b807f051d701a86":[7,0,3,4,10,18],
-"direct__solve_8hpp.html#a2e8b6a07a5428b381a32dce8d176c5cb":[7,0,3,4,10,14],
-"direct__solve_8hpp.html#a35e16c1b6e70e7886f6b9f9899e69d8d":[7,0,3,4,10,9],
-"direct__solve_8hpp.html#a3a61b45de1633dab2c70d4e0f7d6b58e":[7,0,3,4,10,23],
-"direct__solve_8hpp.html#a411e23896112783243250a4af9f11d4f":[7,0,3,4,10,7],
-"direct__solve_8hpp.html#a417b445922558c4143b0e4e68896dfb9":[7,0,3,4,10,20],
-"direct__solve_8hpp.html#a5061bdc14b2973dbeb1a9e7c11ea03fa":[7,0,3,4,10,13],
-"direct__solve_8hpp.html#a53e1955226f40bd11f99c9ab977905a3":[7,0,3,4,10,8],
-"direct__solve_8hpp.html#a66e164b26b4faa2405a7792974d4a7f2":[7,0,3,4,10,19],
-"direct__solve_8hpp.html#a6adb698f5ba8b8fbb2e3d56e5f6caeb4":[7,0,3,4,10,0],
-"direct__solve_8hpp.html#a7b295af009d30ee10ba558b5cae9fcfa":[7,0,3,4,10,27],
-"direct__solve_8hpp.html#a7c455be1ae84ec68521b322301c77877":[7,0,3,4,10,17]
+"dir_01b3c751f720f476f11e734a5342cf1b.html":[7,0,3,2,0,0,1],
+"dir_092b0434a99bb331b2d9b2dab295534c.html":[7,0,3,1],
+"dir_099d776d46ae96ff5cee19885f4f74f2.html":[7,0,2,0],
+"dir_0b4fb0e326d4c389a119669d669a6e69.html":[7,0,3,2,0,0,2,1,0],
+"dir_2001d641ce37c2db2d1e007fffdbbab7.html":[7,0,3,2,0,0,0],
+"dir_27114906f706ecdebcc89e2874337717.html":[7,0,3,2,1],
+"dir_2c76207559b46be39a09cc4d70787ef4.html":[7,0,3,4,1],
+"dir_2f67efd16f85b85ca16db052e014fcaf.html":[7,0,3,2,0,0,2,0],
+"dir_3434f00e33d7f192388fb69bbf2f37a2.html":[7,0,3,5],
+"dir_35f9be625259f60231ebff5b0d077ea2.html":[7,0,0,1],
+"dir_390b8788bc396e89a6deace7ca940934.html":[7,0,3,2,0,0,2,1,3],
+"dir_3c0f8bca876b5668e3f390ae97746303.html":[7,0,3,4,0],
+"dir_41e0e67a22e5e0d73b771322c991061f.html":[7,0,3,4,2],
+"dir_4de6310690561ebe9ac5fd60ffe08037.html":[7,0,3],
+"dir_58fc2bc704609e0f008af69b801200e4.html":[7,0,3,2],
+"dir_59cb328a51f7f6429c345eb686ab7724.html":[7,0,3,2,0,0,2,1,1],
+"dir_5c3e36572ba72092998a3741bd07cdf1.html":[7,0,3,2,0,0,2],
+"dir_5f8f0868158a2d22d511a28fc1cd18ce.html":[7,0,3,9],
+"dir_63a76f200abdc5aa2f86541e7eb7aef8.html":[7,0,3,6],
+"dir_6dca993aa72ebeec8a0f442d956c9913.html":[7,0,2],
+"dir_6f8f0f2d0c4cbbddd33023456e356f61.html":[7,0,3,2,0,0,2,1,2],
+"dir_77930e01897af26f03a43cb7e2da3e4a.html":[7,0,3,4],
+"dir_8118e66653cd7da1a37aaa1607e88630.html":[7,0,3,2,0,0],
+"dir_824564dd709617d4bdedad95258d9046.html":[7,0,3,4,1,1],
+"dir_858444a2a3a03d054aa7433b28efdef9.html":[7,0,3,2,0],
+"dir_8b1ffc44f1138c76b3fbf6563058dc96.html":[7,0,3,3],
+"dir_93563308d5b356d3ecc9c56b5eba5216.html":[7,0,0],
+"dir_95fc417dec4bda27f5b6b357f2a06a36.html":[7,0,1,0],
+"dir_a35454c136dbde0efc3d038671c34f86.html":[7,0,3,4,1,2],
+"dir_c31b5415cda288c5525ed229fcfffcf8.html":[7,0,3,8],
+"dir_c9edeb3d94bf5e327751a8cc5813c8dd.html":[7,0,3,4,1,3],
+"dir_ce8031117faa480542275b5ce9add50d.html":[7,0,3,10],
+"dir_d1898bb18f82202c483fe3a51bff13d4.html":[7,0,3,2,0,0,2,0,2],
+"dir_d23fc3235ab72e0492c7b54726da60e2.html":[7,0,3,2,0,0,2,0,3],
+"dir_d3fb184dc4f20da33396307607cc8bb4.html":[7,0,1],
+"dir_d68073153f76c9008f2e3fe0f69d64d6.html":[7,0,0,0],
+"dir_e2246a470efa11fe5ee09b98569d4f67.html":[7,0,3,4,3,0],
+"dir_e41cc518aa56aa7f9ce018465031b9eb.html":[7,0,3,2,0,0,2,0,0],
+"dir_e8182705ebed9d1d140d832c453ebe92.html":[7,0,1,1],
+"dir_eb859c66d33e4484181fb09db56df864.html":[7,0,3,2,0,0,2,1],
+"dir_ed6f2e67dec54bb764eec12abdb4cfa4.html":[7,0,3,2,0,0,2,0,1],
+"dir_f6bb7da30ce818e127ed2ed164db6395.html":[7,0,3,7],
+"dir_f80b40e4de20372a9d8da07b695e9141.html":[7,0,3,4,1,0],
+"dir_fde5adc25a0fd7501eb505b6744dc8e7.html":[7,0,3,0],
+"dir_fe84e742d5b92d85f104b5626c2ae061.html":[7,0,3,4,3],
+"direct__solve_8cpp.html":[7,0,0,0,1],
+"direct__solve_8cpp.html#a33980228e5f215fd71462379cd1211b9":[7,0,0,0,1,2],
+"direct__solve_8cpp.html#a76c117307d545decb2480596430b8ed0":[7,0,0,0,1,6],
+"direct__solve_8cpp.html#aa65d2e04f3d59333c77d100f1a63c629":[7,0,0,0,1,5],
+"direct__solve_8cpp.html#aabc64c16d2e1b298f71fb50d4ce3415b":[7,0,0,0,1,1],
+"direct__solve_8cpp.html#ad8c59b30c7fc4da98b394ebe66097547":[7,0,0,0,1,7],
+"direct__solve_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18":[7,0,0,0,1,0],
+"direct__solve_8cpp.html#adec2672386c4eb7d3237505be5cdfb8b":[7,0,0,0,1,4],
+"direct__solve_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,1,3],
+"direct__solve_8cpp_source.html":[7,0,0,0,1],
+"direct__solve_8hpp.html":[7,0,3,4,11],
+"direct__solve_8hpp.html#a09afb0da48b9fe60af6bd01f59e31f50":[7,0,3,4,11,5],
+"direct__solve_8hpp.html#a170ab446494c96b18e351a8b26d82166":[7,0,3,4,11,15],
+"direct__solve_8hpp.html#a1c5dfe2ca91ca582638c39016c0a208e":[7,0,3,4,11,21],
+"direct__solve_8hpp.html#a2b533943999da7966b807f051d701a86":[7,0,3,4,11,18],
+"direct__solve_8hpp.html#a2e8b6a07a5428b381a32dce8d176c5cb":[7,0,3,4,11,14],
+"direct__solve_8hpp.html#a35e16c1b6e70e7886f6b9f9899e69d8d":[7,0,3,4,11,9],
+"direct__solve_8hpp.html#a3a61b45de1633dab2c70d4e0f7d6b58e":[7,0,3,4,11,23],
+"direct__solve_8hpp.html#a411e23896112783243250a4af9f11d4f":[7,0,3,4,11,7],
+"direct__solve_8hpp.html#a417b445922558c4143b0e4e68896dfb9":[7,0,3,4,11,20],
+"direct__solve_8hpp.html#a5061bdc14b2973dbeb1a9e7c11ea03fa":[7,0,3,4,11,13],
+"direct__solve_8hpp.html#a53e1955226f40bd11f99c9ab977905a3":[7,0,3,4,11,8],
+"direct__solve_8hpp.html#a66e164b26b4faa2405a7792974d4a7f2":[7,0,3,4,11,19],
+"direct__solve_8hpp.html#a6adb698f5ba8b8fbb2e3d56e5f6caeb4":[7,0,3,4,11,0],
+"direct__solve_8hpp.html#a7b295af009d30ee10ba558b5cae9fcfa":[7,0,3,4,11,27],
+"direct__solve_8hpp.html#a7c455be1ae84ec68521b322301c77877":[7,0,3,4,11,17],
+"direct__solve_8hpp.html#a87b19fc27005f6e13a9ee981965a5e97":[7,0,3,4,11,28],
+"direct__solve_8hpp.html#a8ff7d3cc1ecf2686dcb0795d188ecdf0":[7,0,3,4,11,24],
+"direct__solve_8hpp.html#aacfff27023e7934e8fc91add06a00015":[7,0,3,4,11,2],
+"direct__solve_8hpp.html#aaf694e493220c997a56117180898e34d":[7,0,3,4,11,3],
+"direct__solve_8hpp.html#ab46903287704fb77078a994bbe7450c3":[7,0,3,4,11,4],
+"direct__solve_8hpp.html#ab726081ab01b69a8292d3be04e5fc3e2":[7,0,3,4,11,16],
+"direct__solve_8hpp.html#ac0c2e482814cd46a9dc139af45d5977e":[7,0,3,4,11,29],
+"direct__solve_8hpp.html#ac5653f3afdba6531933d14ed561cece7":[7,0,3,4,11,12],
+"direct__solve_8hpp.html#ac76b5c350f25569a8c503ab102289dfa":[7,0,3,4,11,26],
+"direct__solve_8hpp.html#ac8e8ed654f145cb91cd73e759603683c":[7,0,3,4,11,22],
+"direct__solve_8hpp.html#adf06f61be9418e5817eed66004f9dd2b":[7,0,3,4,11,1],
+"direct__solve_8hpp.html#adf2d1656abbdd59e83cb335f22f94743":[7,0,3,4,11,6],
+"direct__solve_8hpp.html#ae6d7887a8badaa283e9522d63a611a56":[7,0,3,4,11,25],
+"direct__solve_8hpp.html#ae7017a135e4f7d4132fedeadbfc4fec5":[7,0,3,4,11,11],
+"direct__solve_8hpp.html#af31c775455862c55e51fd4119befb8f4":[7,0,3,4,11,10],
+"direct__solve_8hpp_source.html":[7,0,3,4,11],
+"eig_8hpp.html":[7,0,3,4,12],
+"eig_8hpp_source.html":[7,0,3,4,12],
+"eigen-with-viennacl_8cpp-example.html":[8,9],
+"eigen-with-viennacl_8cpp.html":[7,0,0,1,10],
+"eigen-with-viennacl_8cpp_source.html":[7,0,0,1,10],
+"ell__matrix_8hpp.html":[7,0,3,16],
+"ell__matrix_8hpp.html#a86076cab217f7a739775b848fbb2a58f":[7,0,3,16,1],
+"ell__matrix_8hpp.html#a94125a5d77782ecabf9896c4a7378ae6":[7,0,3,16,2],
+"ell__matrix_8hpp.html#adbe5d5ca06633e7eb223bc43df45351d":[7,0,3,16,4],
+"ell__matrix_8hpp.html#aeb9b4abab4a308f6850d8a379ce9d19c":[7,0,3,16,3],
+"ell__matrix_8hpp_source.html":[7,0,3,16],
+"enable__if_8hpp.html":[7,0,3,5,0],
+"enable__if_8hpp_source.html":[7,0,3,5,0],
+"enqueue_8hpp.html":[7,0,3,7,5],
+"enqueue_8hpp.html#a41b8d9b3d5b6fec7edc48484fb2ce3cb":[7,0,3,7,5,4],
+"enqueue_8hpp.html#a5f2022f653ea1cf364d20e3ff84dcada":[7,0,3,7,5,0],
+"enqueue_8hpp.html#a6791536cfb686087f8469152786d17ab":[7,0,3,7,5,2],
+"enqueue_8hpp.html#a7257cac9a7db083d6035053747481a64":[7,0,3,7,5,1],
+"enqueue_8hpp.html#a826887e3aa906648a31b1b41073cb01c":[7,0,3,7,5,3],
+"enqueue_8hpp_source.html":[7,0,3,7,5],
+"entry__proxy_8hpp.html":[7,0,3,9,1],
+"entry__proxy_8hpp_source.html":[7,0,3,9,1],
+"error_8hpp.html":[7,0,3,7,6],
+"error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602":[7,0,3,7,6,54],
+"error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa":[7,0,3,7,6,53],
+"error_8hpp_source.html":[7,0,3,7,6],
+"examples.html":[8],
+"examples_2benchmarks_2sparse_8cpp.html":[7,0,0,0,6],
+"examples_2benchmarks_2sparse_8cpp.html#a3c8d8d5c04fe6deddae061ef4d5945d5":[7,0,0,0,6,5],
+"examples_2benchmarks_2sparse_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,0,0,6,1],
+"examples_2benchmarks_2sparse_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18":[7,0,0,0,6,0],
+"examples_2benchmarks_2sparse_8cpp.html#adec2672386c4eb7d3237505be5cdfb8b":[7,0,0,0,6,4],
+"examples_2benchmarks_2sparse_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,6,3],
+"examples_2benchmarks_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,0,0,6,2],
+"examples_2benchmarks_2sparse_8cpp_source.html":[7,0,0,0,6],
+"examples_2tutorial_2bisect_8cpp.html":[7,0,0,1,3],
+"examples_2tutorial_2bisect_8cpp_source.html":[7,0,0,1,3]
 };
