@@ -1,47 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"classviennacl_1_1const__entry__proxy.html#abc1b268a517bbb435434b9bf54f2313a":[6,0,0,19,4],
-"classviennacl_1_1const__entry__proxy.html#ac364f96496deec7473be1126f12279fc":[6,0,0,19,3],
-"classviennacl_1_1const__entry__proxy.html#afd3d3e90596401bb6cb6309cb6d46fb4":[6,0,0,19,2],
-"classviennacl_1_1const__vector__iterator.html":[6,0,0,20],
-"classviennacl_1_1const__vector__iterator.html#a07e5fcc51a0374b2ce568d8fafed7d53":[6,0,0,20,15],
-"classviennacl_1_1const__vector__iterator.html#a158896d38289f0513c2ca66a62de1883":[6,0,0,20,11],
-"classviennacl_1_1const__vector__iterator.html#a1838b359c2e56e79c515e358841f2bd1":[6,0,0,20,2],
-"classviennacl_1_1const__vector__iterator.html#a2e372df1cde8e780c6255bacc5e0d4fa":[6,0,0,20,3],
-"classviennacl_1_1const__vector__iterator.html#a3fd269ef2b1b32502f2588fc9ef0b20a":[6,0,0,20,9],
-"classviennacl_1_1const__vector__iterator.html#a4c93a6e434c6b18288ec6cbcb75959d6":[6,0,0,20,16],
-"classviennacl_1_1const__vector__iterator.html#a5896558cde67938026b1fa5841443861":[6,0,0,20,0],
-"classviennacl_1_1const__vector__iterator.html#a67270e817fff05ddf59e255f90a2e7a6":[6,0,0,20,5],
-"classviennacl_1_1const__vector__iterator.html#a75ffbe5005aca3d4c5a429c4bd5743ea":[6,0,0,20,4],
-"classviennacl_1_1const__vector__iterator.html#a82c4bf795074b8d05b0d9069916c9e51":[6,0,0,20,8],
-"classviennacl_1_1const__vector__iterator.html#a8937c16730a25f44912fbac6343ff54d":[6,0,0,20,12],
-"classviennacl_1_1const__vector__iterator.html#a98ba9bd7fe31f43438258257dcd4249e":[6,0,0,20,1],
-"classviennacl_1_1const__vector__iterator.html#aa608de6a49490a8a222fe5ffb38526f9":[6,0,0,20,10],
-"classviennacl_1_1const__vector__iterator.html#aa6c4497212e7144b088f9c26a05f2cb5":[6,0,0,20,14],
-"classviennacl_1_1const__vector__iterator.html#abbd5bfa4b7dc793fce6532e94ae80249":[6,0,0,20,7],
-"classviennacl_1_1const__vector__iterator.html#abfc56e2dd63d65539cbb297a7ed96787":[6,0,0,20,17],
-"classviennacl_1_1const__vector__iterator.html#ac9a48f522ed8667681ce24ba68b48973":[6,0,0,20,19],
-"classviennacl_1_1const__vector__iterator.html#acce2d2e5cb157dd10f198f797432549b":[6,0,0,20,13],
-"classviennacl_1_1const__vector__iterator.html#ad0c0c351fcbc964e8a2e26481066c678":[6,0,0,20,6],
-"classviennacl_1_1const__vector__iterator.html#af077a2cd92ce958c587e219b2996ad11":[6,0,0,20,18],
-"classviennacl_1_1context.html":[6,0,0,21],
-"classviennacl_1_1context.html#a88b51d155aee396ef6d8d8a96bd7e90a":[6,0,0,21,1],
-"classviennacl_1_1context.html#a8f95db066e453ccd52aa9305fbd71243":[6,0,0,21,0],
-"classviennacl_1_1context.html#aadf575d49ed144e8fa4707cdad69c349":[6,0,0,21,2],
-"classviennacl_1_1coordinate__matrix.html":[6,0,0,22],
-"classviennacl_1_1coordinate__matrix.html#a04c51b826e4bae9c97a3749ee2161b87":[6,0,0,22,13],
-"classviennacl_1_1coordinate__matrix.html#a2035ac2e7acc39c21cf13bb6f9c2dc08":[6,0,0,22,12],
-"classviennacl_1_1coordinate__matrix.html#a3cd8e9989ee1b547dbcba2fe87f7b29d":[6,0,0,22,18],
-"classviennacl_1_1coordinate__matrix.html#a472604b5e8e7a818fcee171898df1c92":[6,0,0,22,6],
-"classviennacl_1_1coordinate__matrix.html#a4a8183e8f8e3a91e379d12ada4943b99":[6,0,0,22,17],
-"classviennacl_1_1coordinate__matrix.html#a4fccbe4157aa8833d23b0541803e06af":[6,0,0,22,7],
-"classviennacl_1_1coordinate__matrix.html#a5363ed7b82aaad8549c85d880755f846":[6,0,0,22,15],
-"classviennacl_1_1coordinate__matrix.html#a5497d1e7fdce125b7a5bd12530002b4f":[6,0,0,22,0],
-"classviennacl_1_1coordinate__matrix.html#a626ac84303ae01ac4f7e964f2c2972b6":[6,0,0,22,3],
-"classviennacl_1_1coordinate__matrix.html#a66b7f5c5487b719c91bc76984f89f97f":[6,0,0,22,11],
-"classviennacl_1_1coordinate__matrix.html#a734ed32ff1858ef5453c170326fda377":[6,0,0,22,16],
-"classviennacl_1_1coordinate__matrix.html#a7f83ad82b3bab755d76e7f9d665367f7":[6,0,0,22,8],
-"classviennacl_1_1coordinate__matrix.html#a875b6ccacbf0df8ef48ab7f7c46244f1":[6,0,0,22,10],
 "classviennacl_1_1coordinate__matrix.html#a9cde8a8c5cb1516c5503d011388daed4":[6,0,0,22,4],
 "classviennacl_1_1coordinate__matrix.html#a9fd9168600c330faa69cae2626509602":[6,0,0,22,2],
 "classviennacl_1_1coordinate__matrix.html#ad091412ca52bb131234464ed3f5b103c":[6,0,0,22,14],
@@ -205,8 +163,8 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#ace084027c47cb4c20b091e33774dcfbd":[6,0,0,2,1,0,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#adb18331e422fee5141086cad436f265c":[6,0,0,2,1,0,1],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html":[6,0,0,2,1,1],
+"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#a985282bbdfb34ae6777efc4737d45c00":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#ad3a7c359b39226b4c63c4efb7e246b35":[6,0,0,2,1,1,1],
-"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aeafc307c76220bbc238bd7147a884c17":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aef355f4ccd06d80399b9561283c66eb6":[6,0,0,2,1,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html":[6,0,0,2,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html#a3bd51f61962e2b5ed602d3a19a726cb7":[6,0,0,2,1,2,1],
@@ -249,5 +207,47 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1ell__matrix.html#a4a44645aaf484b5ae5261e54164f8e88":[6,0,0,25,4],
 "classviennacl_1_1ell__matrix.html#a4c3710d18fd3af8d519a0746bdb60bd3":[6,0,0,25,9],
 "classviennacl_1_1ell__matrix.html#a7a37f6e784757bd80c71f800efcefc3f":[6,0,0,25,16],
-"classviennacl_1_1ell__matrix.html#a7fe5450dbe53bb797938aa920d4bbb68":[6,0,0,25,6]
+"classviennacl_1_1ell__matrix.html#a7fe5450dbe53bb797938aa920d4bbb68":[6,0,0,25,6],
+"classviennacl_1_1ell__matrix.html#a8575f900add9d7ff93f73063ac90b4b9":[6,0,0,25,2],
+"classviennacl_1_1ell__matrix.html#a906c21cc40724b86f7f0cf636dc91f60":[6,0,0,25,0],
+"classviennacl_1_1ell__matrix.html#ac9fdc9e7cf3e57e1a9589c52b583a6d7":[6,0,0,25,1],
+"classviennacl_1_1ell__matrix.html#ae29cafe3078a0f6cc9f5a525a1f74f8f":[6,0,0,25,3],
+"classviennacl_1_1ell__matrix.html#ae3280590756e720a8d8dacdeed4b702a":[6,0,0,25,10],
+"classviennacl_1_1ell__matrix.html#aebd34a16c075d010736102865b0c9e29":[6,0,0,25,17],
+"classviennacl_1_1ell__matrix.html#aefdee554c0ef34d0f69e69f788030864":[6,0,0,25,15],
+"classviennacl_1_1ell__matrix.html#af2e571bfc69f9f0acf3e9b19ce2b9b9f":[6,0,0,25,12],
+"classviennacl_1_1ell__matrix.html#af52325d0e501652d68ca5be85d3ea98c":[6,0,0,25,14],
+"classviennacl_1_1ell__matrix.html#afeb18c524920cfa52a7d56cd0b31b3c1":[6,0,0,25,18],
+"classviennacl_1_1ell__matrix.html#aff440baf9a08f63a1aa886990aaf406b":[6,0,0,25,5],
+"classviennacl_1_1entry__proxy.html":[6,0,0,27],
+"classviennacl_1_1entry__proxy.html#a1501c30738b60067172267d936c58dcb":[6,0,0,27,6],
+"classviennacl_1_1entry__proxy.html#a37b3fb6e74d991af47f8d32f1dda6c23":[6,0,0,27,4],
+"classviennacl_1_1entry__proxy.html#a48baf86c6dd5f920bc55b011d832788d":[6,0,0,27,2],
+"classviennacl_1_1entry__proxy.html#a59ddb22fd76964d1e5aae646473f9037":[6,0,0,27,10],
+"classviennacl_1_1entry__proxy.html#a5a5957e985504d3e7cf499407f25c9f2":[6,0,0,27,7],
+"classviennacl_1_1entry__proxy.html#a63ef5534007af719594dc60d0c5781f1":[6,0,0,27,1],
+"classviennacl_1_1entry__proxy.html#a771d0d5e6f898d1680b3f8b6059d31ac":[6,0,0,27,8],
+"classviennacl_1_1entry__proxy.html#a7bf17a30153814b8e7855faf18fdd768":[6,0,0,27,0],
+"classviennacl_1_1entry__proxy.html#a8a00214579b33b0f5d6e022cfd10bedd":[6,0,0,27,5],
+"classviennacl_1_1entry__proxy.html#ac21d5341e24b2aa63ed578f8c15afee0":[6,0,0,27,11],
+"classviennacl_1_1entry__proxy.html#ac4d407afb54158096a97a560ec9b169e":[6,0,0,27,9],
+"classviennacl_1_1entry__proxy.html#adc55b3b64bb7f9e78851d294639a17ba":[6,0,0,27,3],
+"classviennacl_1_1hankel__matrix.html":[6,0,0,29],
+"classviennacl_1_1hankel__matrix.html#a1fbac16688ba2b0a19d01fd7a8fab24f":[6,0,0,29,2],
+"classviennacl_1_1hankel__matrix.html#a2ca803773036e3301662f3a4ced06513":[6,0,0,29,5],
+"classviennacl_1_1hankel__matrix.html#a3a303ed0b61a75c3ffd75112bf61b558":[6,0,0,29,12],
+"classviennacl_1_1hankel__matrix.html#a43654fc305980d2a437769d12d5cc84f":[6,0,0,29,4],
+"classviennacl_1_1hankel__matrix.html#a7e7f884fed71f2788b57a130bcfbf4a0":[6,0,0,29,7],
+"classviennacl_1_1hankel__matrix.html#a993abaae40c5fbb82c3317ae34ac66b2":[6,0,0,29,8],
+"classviennacl_1_1hankel__matrix.html#aaa2c575a8c1610216885136d43625749":[6,0,0,29,10],
+"classviennacl_1_1hankel__matrix.html#aaf5e49a335315a70ff47f3ff8cc4242d":[6,0,0,29,6],
+"classviennacl_1_1hankel__matrix.html#abdb174b8cb98f87d0092b25ebf5a3c64":[6,0,0,29,9],
+"classviennacl_1_1hankel__matrix.html#ac34afa167dfc0fb8dc91757bb677eec9":[6,0,0,29,3],
+"classviennacl_1_1hankel__matrix.html#ae413c0e546c764e3fcf919cb0248739a":[6,0,0,29,11],
+"classviennacl_1_1hankel__matrix.html#af0cf795b18e66655356e2e27fa66d4c7":[6,0,0,29,0],
+"classviennacl_1_1hankel__matrix.html#afd888bb3d2508de274684d1cb8fe5d0b":[6,0,0,29,1],
+"classviennacl_1_1hyb__matrix.html":[6,0,0,30],
+"classviennacl_1_1hyb__matrix.html#a2b1b27a7e14035e94742129e5b6c00b5":[6,0,0,30,12],
+"classviennacl_1_1hyb__matrix.html#a2f620a72f3f44c563dd9fdcd9c788324":[6,0,0,30,15],
+"classviennacl_1_1hyb__matrix.html#a3863e14e65c82bffbd5ac3f42ae72ffc":[6,0,0,30,7]
 };
