@@ -6,6 +6,8 @@ var searchData=
   ['zero2',['zero2',['../namespaceviennacl_1_1linalg_1_1cuda.html#ac939f8ae31fdf532db77b38aa3a264f9',1,'viennacl::linalg::cuda::zero2()'],['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html#ac7be4ca00fcfb8603deac9c9d4e15da7',1,'viennacl::linalg::host_based::detail::fft::zero2()']]],
   ['zero_5fmatrix',['zero_matrix',['../classviennacl_1_1zero__matrix.html#a08bdbe7ffa489ba99710d3b71bae73ae',1,'viennacl::zero_matrix']]],
   ['zero_5fmatrix',['zero_matrix',['../classviennacl_1_1zero__matrix.html',1,'viennacl']]],
-  ['zero_5fvector',['zero_vector',['../structviennacl_1_1zero__vector.html#ae406c3ad1bd132d101ad3f3721afcdd2',1,'viennacl::zero_vector']]],
-  ['zero_5fvector',['zero_vector',['../structviennacl_1_1zero__vector.html',1,'viennacl']]]
+  ['zero_5fon_5fdiagonal_5fexception',['zero_on_diagonal_exception',['../classviennacl_1_1zero__on__diagonal__exception.html#adf4c689405ac0c75dc16bc50442cb949',1,'viennacl::zero_on_diagonal_exception']]],
+  ['zero_5fon_5fdiagonal_5fexception',['zero_on_diagonal_exception',['../classviennacl_1_1zero__on__diagonal__exception.html',1,'viennacl']]],
+  ['zero_5fvector',['zero_vector',['../structviennacl_1_1zero__vector.html',1,'viennacl']]],
+  ['zero_5fvector',['zero_vector',['../structviennacl_1_1zero__vector.html#ae406c3ad1bd132d101ad3f3721afcdd2',1,'viennacl::zero_vector']]]
 ];
