@@ -1,11 +1,16 @@
 var searchData=
 [
+  ['cg_5fsolver',['cg_solver',['../classviennacl_1_1linalg_1_1cg__solver.html',1,'viennacl::linalg']]],
   ['cg_5ftag',['cg_tag',['../classviennacl_1_1linalg_1_1cg__tag.html',1,'viennacl::linalg']]],
   ['char_5fto_5ftype',['char_to_type',['../structviennacl_1_1device__specific_1_1char__to__type.html',1,'viennacl::device_specific']]],
   ['check_5fscalar_5ftemplate_5fargument',['CHECK_SCALAR_TEMPLATE_ARGUMENT',['../structviennacl_1_1tools_1_1_c_h_e_c_k___s_c_a_l_a_r___t_e_m_p_l_a_t_e___a_r_g_u_m_e_n_t.html',1,'viennacl::tools']]],
+  ['chow_5fpatel_5ficc_5fprecond',['chow_patel_icc_precond',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond.html',1,'viennacl::linalg']]],
+  ['chow_5fpatel_5ficc_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_icc_precond< viennacl::compressed_matrix< NumericT, AlignmentV > >',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond_3_01viennacl_1_1compressed__matrix_3_01_num12c156ca568277646db4ffa0c9da3134.html',1,'viennacl::linalg']]],
+  ['chow_5fpatel_5filu_5fprecond',['chow_patel_ilu_precond',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond.html',1,'viennacl::linalg']]],
+  ['chow_5fpatel_5filu_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_ilu_precond< viennacl::compressed_matrix< NumericT, AlignmentV > >',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond_3_01viennacl_1_1compressed__matrix_3_01_num1d4c01a16bf6e4ce8c15fcd9140c68ca.html',1,'viennacl::linalg']]],
+  ['chow_5fpatel_5ftag',['chow_patel_tag',['../classviennacl_1_1linalg_1_1chow__patel__tag.html',1,'viennacl::linalg']]],
   ['circulant_5fmatrix',['circulant_matrix',['../classviennacl_1_1circulant__matrix.html',1,'viennacl']]],
   ['cl_5ftype',['cl_type',['../structviennacl_1_1result__of_1_1cl__type.html',1,'viennacl::result_of']]],
-  ['classcomp',['classcomp',['../structviennacl_1_1linalg_1_1detail_1_1amg_1_1classcomp.html',1,'viennacl::linalg::detail::amg']]],
   ['col_5fiteration',['col_iteration',['../structviennacl_1_1col__iteration.html',1,'viennacl']]],
   ['column_5fmajor',['column_major',['../structviennacl_1_1column__major.html',1,'viennacl']]],
   ['column_5fmajor_5ftag',['column_major_tag',['../structviennacl_1_1column__major__tag.html',1,'viennacl']]],
@@ -26,11 +31,11 @@ var searchData=
   ['const_5fsparse_5fmatrix_5fadapted_5fiterator',['const_sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
   ['const_5fsparse_5fmatrix_5fadapter',['const_sparse_matrix_adapter',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html',1,'viennacl::tools']]],
   ['const_5fvector_5fiterator',['const_vector_iterator',['../classviennacl_1_1const__vector__iterator.html',1,'viennacl']]],
-  ['context',['context',['../classviennacl_1_1context.html',1,'viennacl']]],
   ['context',['context',['../classviennacl_1_1ocl_1_1context.html',1,'viennacl::ocl']]],
+  ['context',['context',['../classviennacl_1_1context.html',1,'viennacl']]],
   ['convert_5fto_5fopencl',['convert_to_opencl',['../structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html',1,'viennacl::backend::detail']]],
-  ['coordinate_5fmatrix',['coordinate_matrix',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
   ['coordinate_5fmatrix',['coordinate_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
+  ['coordinate_5fmatrix',['coordinate_matrix',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
   ['coordinate_5fmatrix_3c_20double_20_3e',['coordinate_matrix< double >',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
   ['coordinate_5fmatrix_3c_20float_20_3e',['coordinate_matrix< float >',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
   ['count',['count',['../classviennacl_1_1tools_1_1detail_1_1count.html',1,'viennacl::tools::detail']]],
@@ -38,6 +43,7 @@ var searchData=
   ['cpu_5ftag',['cpu_tag',['../structviennacl_1_1ocl_1_1cpu__tag.html',1,'viennacl::ocl']]],
   ['cpu_5fvalue_5ftype',['cpu_value_type',['../structviennacl_1_1result__of_1_1cpu__value__type.html',1,'viennacl::result_of']]],
   ['cuda_5fdeleter',['cuda_deleter',['../structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html',1,'viennacl::backend::cuda::detail']]],
+  ['cuda_5fexception',['cuda_exception',['../classviennacl_1_1backend_1_1cuda_1_1cuda__exception.html',1,'viennacl::backend::cuda']]],
   ['cuda_5fnot_5favailable_5fexception',['cuda_not_available_exception',['../classviennacl_1_1cuda__not__available__exception.html',1,'viennacl']]],
   ['cuthill_5fmckee_5ftag',['cuthill_mckee_tag',['../structviennacl_1_1cuthill__mckee__tag.html',1,'viennacl']]]
 ];
