@@ -22,6 +22,7 @@ var searchData=
   ['mat_5fmult_5fmatrix_5findex',['mat_mult_matrix_index',['../structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html',1,'viennacl::linalg::cuda']]],
   ['matrix',['matrix',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html',1,'viennacl::linalg::opencl::kernels']]],
   ['matrix',['matrix',['../classviennacl_1_1matrix.html',1,'viennacl']]],
+  ['matrix_3c_20numerict_20_3e',['matrix< NumericT >',['../classviennacl_1_1matrix.html',1,'viennacl']]],
   ['matrix_5farray_5fwrapper',['matrix_array_wrapper',['../classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html',1,'viennacl::linalg::host_based::detail']]],
   ['matrix_5faxpy_5fparameters_5ftype',['matrix_axpy_parameters_type',['../classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html',1,'viennacl::device_specific']]],
   ['matrix_5faxpy_5ftemplate',['matrix_axpy_template',['../classviennacl_1_1device__specific_1_1matrix__axpy__template.html',1,'viennacl::device_specific']]],
@@ -38,6 +39,7 @@ var searchData=
   ['matrix_5fbase_3c_20unsigned_20int_20_3e',['matrix_base< unsigned int >',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
   ['matrix_5fbase_3c_20unsigned_20long_20_3e',['matrix_base< unsigned long >',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
   ['matrix_5fbase_3c_20unsigned_20short_20_3e',['matrix_base< unsigned short >',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
+  ['matrix_5fconvert',['matrix_convert',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__convert.html',1,'viennacl::linalg::opencl::kernels']]],
   ['matrix_5felement',['matrix_element',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html',1,'viennacl::linalg::opencl::kernels']]],
   ['matrix_5fexpression',['matrix_expression',['../classviennacl_1_1matrix__expression.html',1,'viennacl']]],
   ['matrix_5fiterator',['matrix_iterator',['../classviennacl_1_1matrix__iterator.html',1,'viennacl']]],
