@@ -7,11 +7,12 @@ var searchData=
   ['op_5fargmax',['op_argmax',['../structviennacl_1_1op__argmax.html',1,'viennacl']]],
   ['op_5fargmin',['op_argmin',['../structviennacl_1_1op__argmin.html',1,'viennacl']]],
   ['op_5fasin',['op_asin',['../structviennacl_1_1op__asin.html',1,'viennacl']]],
-  ['op_5fassign',['op_assign',['../structop__assign.html',1,'']]],
   ['op_5fassign',['op_assign',['../structviennacl_1_1op__assign.html',1,'viennacl']]],
+  ['op_5fassign',['op_assign',['../structop__assign.html',1,'']]],
   ['op_5fatan',['op_atan',['../structviennacl_1_1op__atan.html',1,'viennacl']]],
   ['op_5fatan2',['op_atan2',['../structviennacl_1_1op__atan2.html',1,'viennacl']]],
   ['op_5fceil',['op_ceil',['../structviennacl_1_1op__ceil.html',1,'viennacl']]],
+  ['op_5fcol_5fsum',['op_col_sum',['../structviennacl_1_1op__col__sum.html',1,'viennacl']]],
   ['op_5fcolumn',['op_column',['../structviennacl_1_1op__column.html',1,'viennacl']]],
   ['op_5fcos',['op_cos',['../structviennacl_1_1op__cos.html',1,'viennacl']]],
   ['op_5fcosh',['op_cosh',['../structviennacl_1_1op__cosh.html',1,'viennacl']]],
@@ -53,14 +54,13 @@ var searchData=
   ['op_5fplus_5fassign',['op_plus_assign',['../structop__plus__assign.html',1,'']]],
   ['op_5fpow',['op_pow',['../structviennacl_1_1op__pow.html',1,'viennacl']]],
   ['op_5fprod',['op_prod',['../structviennacl_1_1op__prod.html',1,'viennacl']]],
-  ['op_5freduce_5fcolumns',['op_reduce_columns',['../structviennacl_1_1op__reduce__columns.html',1,'viennacl']]],
-  ['op_5freduce_5frows',['op_reduce_rows',['../structviennacl_1_1op__reduce__rows.html',1,'viennacl']]],
-  ['op_5freduce_5fvector',['op_reduce_vector',['../structviennacl_1_1op__reduce__vector.html',1,'viennacl']]],
   ['op_5frow',['op_row',['../structviennacl_1_1op__row.html',1,'viennacl']]],
+  ['op_5frow_5fsum',['op_row_sum',['../structviennacl_1_1op__row__sum.html',1,'viennacl']]],
   ['op_5fsin',['op_sin',['../structviennacl_1_1op__sin.html',1,'viennacl']]],
   ['op_5fsinh',['op_sinh',['../structviennacl_1_1op__sinh.html',1,'viennacl']]],
   ['op_5fsqrt',['op_sqrt',['../structviennacl_1_1op__sqrt.html',1,'viennacl']]],
   ['op_5fsub',['op_sub',['../structviennacl_1_1op__sub.html',1,'viennacl']]],
+  ['op_5fsum',['op_sum',['../structviennacl_1_1op__sum.html',1,'viennacl']]],
   ['op_5ftan',['op_tan',['../structviennacl_1_1op__tan.html',1,'viennacl']]],
   ['op_5ftanh',['op_tanh',['../structviennacl_1_1op__tanh.html',1,'viennacl']]],
   ['op_5ftrans',['op_trans',['../structviennacl_1_1op__trans.html',1,'viennacl']]],
@@ -122,9 +122,6 @@ var searchData=
   ['op_5ftype_5finfo_3c_20op_5fnorm_5f2_20_3e',['op_type_info< op_norm_2 >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__2_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fnorm_5finf_20_3e',['op_type_info< op_norm_inf >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__inf_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fprod_20_3e',['op_type_info< op_prod >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__prod_01_4.html',1,'viennacl::scheduler::result_of']]],
-  ['op_5ftype_5finfo_3c_20op_5freduce_5fcolumns_3c_20op_20_3e_20_3e',['op_type_info< op_reduce_columns< OP > >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__columns_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
-  ['op_5ftype_5finfo_3c_20op_5freduce_5frows_3c_20op_20_3e_20_3e',['op_type_info< op_reduce_rows< OP > >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__rows_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
-  ['op_5ftype_5finfo_3c_20op_5freduce_5fvector_3c_20op_20_3e_20_3e',['op_type_info< op_reduce_vector< OP > >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__vector_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5frow_20_3e',['op_type_info< op_row >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__row_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fsub_20_3e',['op_type_info< op_sub >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__sub_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5ftrans_20_3e',['op_type_info< op_trans >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__trans_01_4.html',1,'viennacl::scheduler::result_of']]],
