@@ -20,9 +20,11 @@ var searchData=
   ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5f2_20_3e',['scalar_expression< LHS, RHS, op_norm_2 >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html',1,'viennacl']]],
   ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5ffrobenius_20_3e',['scalar_expression< LHS, RHS, op_norm_frobenius >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html',1,'viennacl']]],
   ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5finf_20_3e',['scalar_expression< LHS, RHS, op_norm_inf >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html',1,'viennacl']]],
+  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fsum_20_3e',['scalar_expression< LHS, RHS, op_sum >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__sum_01_4.html',1,'viennacl']]],
   ['scalar_5fmatrix',['scalar_matrix',['../classviennacl_1_1scalar__matrix.html',1,'viennacl']]],
   ['scalar_5fvector',['scalar_vector',['../structviennacl_1_1scalar__vector.html',1,'viennacl']]],
   ['scalartype_5fsize_5ffun',['scalartype_size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html',1,'viennacl::device_specific::utils']]],
+  ['scan',['scan',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scan.html',1,'viennacl::linalg::opencl::kernels']]],
   ['sha1',['sha1',['../classviennacl_1_1tools_1_1detail_1_1sha1.html',1,'viennacl::tools::detail']]],
   ['shared_5fptr',['shared_ptr',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
   ['shared_5fptr_3c_20char_20_3e',['shared_ptr< char >',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
@@ -39,6 +41,8 @@ var searchData=
   ['sparse_5fmatrix_5fadapted_5fiterator',['sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
   ['sparse_5fmatrix_5fadapter',['sparse_matrix_adapter',['../classviennacl_1_1tools_1_1sparse__matrix__adapter.html',1,'viennacl::tools']]],
   ['sparse_5fvector',['sparse_vector',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html',1,'viennacl::linalg::detail::spai']]],
+  ['spgemm_5foutput_5fwrite_5fdisabled',['spgemm_output_write_disabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__disabled.html',1,'viennacl::linalg::host_based']]],
+  ['spgemm_5foutput_5fwrite_5fenabled',['spgemm_output_write_enabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__enabled.html',1,'viennacl::linalg::host_based']]],
   ['start1_5ffun',['start1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html',1,'viennacl::device_specific::utils']]],
   ['start2_5ffun',['start2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html',1,'viennacl::device_specific::utils']]],
   ['statement',['statement',['../classviennacl_1_1scheduler_1_1statement.html',1,'viennacl::scheduler']]],
