@@ -1,9 +1,7 @@
 var searchData=
 [
-  ['random_2ehpp',['Random.hpp',['../tests_2src_2_random_8hpp.html',1,'']]],
-  ['random_2ehpp',['Random.hpp',['../examples_2tutorial_2_random_8hpp.html',1,'']]],
+  ['random_2ehpp',['random.hpp',['../random_8hpp.html',1,'']]],
   ['range_2ehpp',['range.hpp',['../range_8hpp.html',1,'']]],
-  ['reduce_2ehpp',['reduce.hpp',['../reduce_8hpp.html',1,'']]],
   ['reduction_2ehpp',['reduction.hpp',['../reduction_8hpp.html',1,'']]],
   ['reduction_5ftemplate_2ehpp',['reduction_template.hpp',['../reduction__template_8hpp.html',1,'']]],
   ['result_5fof_2ehpp',['result_of.hpp',['../result__of_8hpp.html',1,'']]],
