@@ -1,16 +1,16 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghijklmnopqrstuvwz~",
-  1: "abcdefghijklmnoprstuvz",
+  0: "abcdefghijklmnopqrstuvwz~",
+  1: "abcdefghijklmnopqrstuvz",
   2: "dv",
   3: "abcdefghijklmnopqrstuvw",
-  4: "_abcdefghijklmnopqrstuvwz~",
+  4: "abcdefghijklmnopqrstuvwz~",
   5: "abcdefghijklmnoprstvw",
-  6: "acdefhimoprstv",
+  6: "cdefhimnoprstuv",
   7: "abdeflmorsv",
   8: "abcdefhiklmnoprstuv",
   9: "cens",
-  10: "bdegntv",
+  10: "bdegnrtv",
   11: "abcdfilmstuv"
 };
 
