@@ -1,8 +1,6 @@
 var searchData=
 [
-  ['threads_5f',['threads_',['../classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html#af0209ddf1eb279f1128f57e890783b84',1,'viennacl::linalg::detail::amg::amg_slicing']]],
   ['trans',['trans',['../struct_vienna_c_l_matrix__impl.html#ae33a64dcfb8dfe7234dddc3270838bec',1,'ViennaCLMatrix_impl']]],
-  ['transposematrix',['transposeMatrix',['../fft__2d_8cpp.html#a69eff661bdd2926d2d408c96b1c485de',1,'fft_2d.cpp']]],
   ['type',['type',['../structviennacl_1_1scheduler_1_1op__element.html#ad85def5d25e684d04c738cf030d3ba09',1,'viennacl::scheduler::op_element']]],
   ['type_5ffamily',['type_family',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#af1fe6cba4b0eb3bb5f41a3eea7744a78',1,'viennacl::scheduler::lhs_rhs_element::type_family()'],['../structviennacl_1_1scheduler_1_1op__element.html#a935547a375e550b11a98b088297486e5',1,'viennacl::scheduler::op_element::type_family()']]],
   ['type_5fkey_5f',['type_key_',['../classviennacl_1_1device__specific_1_1mapped__object.html#aedb02cc827e6c02771346a3dacbdf971',1,'viennacl::device_specific::mapped_object']]]
