@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -50,13 +50,8 @@
 #include "viennacl/vector.hpp"
 #include "viennacl/matrix.hpp"
 #include "viennacl/linalg/prod.hpp"
-
-
-// Some helper functions for this tutorial:
-#include "Random.hpp"
-#include "vector-io.hpp"
-
-#include "../benchmarks/benchmark-utils.hpp"
+#include "viennacl/tools/random.hpp"
+#include "viennacl/tools/timer.hpp"
 
 #define BLAS3_MATRIX_SIZE   400
 
@@ -81,9 +76,11 @@ int main()
 {
   typedef float     ScalarType;
 
-  Timer timer;
+  viennacl::tools::timer timer;
   double exec_time;
 
+  viennacl::tools::uniform_random_numbers<ScalarType> randomNumber;
+
   /**
   * Set up some ublas objects and initialize with data:
   **/
@@ -94,11 +91,11 @@ int main()
 
   for (unsigned int i = 0; i < ublas_A.size1(); ++i)
     for (unsigned int j = 0; j < ublas_A.size2(); ++j)
-      ublas_A(i,j) = random<ScalarType>();
+      ublas_A(i,j) = randomNumber();
 
   for (unsigned int i = 0; i < ublas_B.size1(); ++i)
     for (unsigned int j = 0; j < ublas_B.size2(); ++j)
-      ublas_B(i,j) = random<ScalarType>();
+      ublas_B(i,j) = randomNumber();
 
   /**
   * Set up some ViennaCL objects. Data initialization will happen later.
