@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -40,11 +40,6 @@
 #include "viennacl/linalg/prod.hpp"
 
 
-// Some helper functions for this tutorial:
-#include "Random.hpp"
-
-
-
 
 /** <h2>Defining a Compute Kernel</h2>
 *
