@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -37,10 +37,6 @@
 #include "viennacl/linalg/norm_2.hpp"
 
 
-// Some helper functions for this tutorial:
-#include "Random.hpp"
-
-
 /**
 * The next step is to define the custom compute kernels in a string.
 * It is assumed that you are familiar with writing basic OpenCL kernels.
