@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -48,9 +48,7 @@
 
 
 // Some helper functions for this tutorial:
-#include "Random.hpp"
 #include "vector-io.hpp"
-#include "../benchmarks/benchmark-utils.hpp"
 
 /**
 *  In the following we run the CG method, the BiCGStab method, and the GMRES method with Eigen types directly.
