@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -58,8 +58,7 @@
 #include "viennacl/linalg/ilu.hpp"
 #include "viennacl/linalg/detail/ilu/common.hpp"
 #include "viennacl/io/matrix_market.hpp"
-#include "examples/tutorial/Random.hpp"
-#include "examples/tutorial/vector-io.hpp"
+#include "viennacl/tools/random.hpp"
 
 #include "viennacl/scheduler/execute.hpp"
 #include "viennacl/scheduler/io.hpp"
@@ -181,6 +180,8 @@ int test(Epsilon const& epsilon)
 {
   int retval = EXIT_SUCCESS;
 
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   // --------------------------------------------------------------------------
   NumericT alpha = static_cast<NumericT>(2.786);
   NumericT beta = static_cast<NumericT>(1.432);
@@ -202,7 +203,7 @@ int test(Epsilon const& epsilon)
   for (std::size_t i=0; i<rhs.size(); ++i)
   {
     ublas_matrix(i,i) = NumericT(0.5);   // Get rid of round-off errors by making row-sums unequal to zero:
-    rhs[i] = NumericT(1) + random<NumericT>();
+    rhs[i] = NumericT(1) + randomNumber();
   }
 
   result = rhs;
