@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -49,8 +49,8 @@
 #include "viennacl/linalg/ilu.hpp"
 #include "viennacl/linalg/detail/ilu/common.hpp"
 #include "viennacl/io/matrix_market.hpp"
-#include "examples/tutorial/Random.hpp"
-#include "examples/tutorial/vector-io.hpp"
+#include "viennacl/tools/random.hpp"
+
 
 //
 // -------------------------------------------------------------
@@ -165,11 +165,13 @@ void test_gemm(NumericT epsilon,
                DeviceMatrixT & device_C, bool copy_from_A,
                bool trans_first, bool trans_second)
 {
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   for (std::size_t i = 0; i<host_A.size(); ++i)
     for (std::size_t j = 0; j<host_A[i].size(); ++j)
     {
-      host_A[i][j] = random<NumericT>();
-      host_B[i][j] = random<NumericT>();
+      host_A[i][j] = randomNumber();
+      host_B[i][j] = randomNumber();
     }
 
   viennacl::copy(host_A, device_A);
@@ -234,6 +236,8 @@ int test(NumericT epsilon)
 {
   std::size_t N = 142; // should be larger than 128 in order to avoid false negatives due to blocking
 
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   //
   // Vector setup and test:
   //
@@ -302,16 +306,16 @@ int test(NumericT epsilon)
   vcl_x = viennacl::linalg::prod(vcl_A, vcl_x);
   check(std_y, vcl_x, "x = A*x", epsilon);
 
-
-  std::vector< std::map<unsigned int, NumericT> > std_Asparse(N);
+  typedef unsigned int     KeyType;
+  std::vector< std::map<KeyType, NumericT> > std_Asparse(N);
 
   for (std::size_t i=0; i<std_Asparse.size(); ++i)
   {
     if (i > 0)
-      std_Asparse[i][i-1] = random<NumericT>();
-    std_Asparse[i][i] = NumericT(1) + random<NumericT>();
+      std_Asparse[i][KeyType(i-1)] = randomNumber();
+    std_Asparse[i][KeyType(i)] = NumericT(1) + randomNumber();
     if (i < std_Asparse.size() - 1)
-      std_Asparse[i][i+1] = random<NumericT>();
+      std_Asparse[i][KeyType(i+1)] = randomNumber();
   }
 
   // Sparse
@@ -387,7 +391,7 @@ int test(NumericT epsilon)
     {
       NumericT tmp = 0;
       for (std::size_t k = 0; k<std_A[i].size(); ++k)
-        tmp += std_Asparse[i][k] * std_A[k][j];
+        tmp += std_Asparse[i][KeyType(k)] * std_A[k][j];
       std_C[i][j] = tmp;
     }
 
@@ -418,7 +422,7 @@ int test(NumericT epsilon)
     {
       NumericT tmp = 0;
       for (std::size_t k = 0; k<std_A[i].size(); ++k)
-        tmp += std_Asparse[i][k] * std_A[j][k];
+        tmp += std_Asparse[i][KeyType(k)] * std_A[j][k];
       std_C[i][j] = tmp;
     }
 
