@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -15,6 +15,12 @@
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
 
+
+
+/** \file tests/src/sparse.cpp  Tests sparse matrix operations.
+*   \test  Tests sparse matrix operations.
+**/
+
 #ifndef NDEBUG
  #define NDEBUG
 #endif
@@ -47,6 +53,7 @@
 #include "viennacl/compressed_compressed_matrix.hpp"
 #include "viennacl/coordinate_matrix.hpp"
 #include "viennacl/ell_matrix.hpp"
+#include "viennacl/sliced_ell_matrix.hpp"
 #include "viennacl/hyb_matrix.hpp"
 #include "viennacl/vector.hpp"
 #include "viennacl/vector_proxy.hpp"
@@ -55,8 +62,8 @@
 #include "viennacl/linalg/ilu.hpp"
 #include "viennacl/linalg/detail/ilu/common.hpp"
 #include "viennacl/io/matrix_market.hpp"
-#include "examples/tutorial/Random.hpp"
-#include "examples/tutorial/vector-io.hpp"
+#include "viennacl/tools/random.hpp"
+
 
 //
 // -------------------------------------------------------------
@@ -65,7 +72,7 @@ using namespace boost::numeric;
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
 {
    if (s1 != s2)
@@ -73,7 +80,7 @@ ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
    return 0;
 }
 
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ublas::vector<ScalarType> & v1, viennacl::vector<ScalarType> & v2)
 {
    ublas::vector<ScalarType> v2_cpu(v2.size());
@@ -95,7 +102,7 @@ ScalarType diff(ublas::vector<ScalarType> & v1, viennacl::vector<ScalarType> & v
       if (v2_cpu[i] > 0.0001)
       {
         //std::cout << "Neighbor: "      << i-1 << ": " << v1[i-1] << " vs. " << v2_cpu[i-1] << std::endl;
-        std::cout << "Error at entry " << i   << ": " << v1[i]   << " vs. " << v2_cpu[i]   << std::endl;
+        std::cout << "Error at entry " << i   << ": Should: " << v1[i]   << " vs. Is: " << v2[i]   << std::endl;
         //std::cout << "Neighbor: "      << i+1 << ": " << v1[i+1] << " vs. " << v2_cpu[i+1] << std::endl;
         exit(EXIT_FAILURE);
       }
@@ -105,7 +112,7 @@ ScalarType diff(ublas::vector<ScalarType> & v1, viennacl::vector<ScalarType> & v
 }
 
 
-template <typename ScalarType, typename VCL_MATRIX>
+template<typename ScalarType, typename VCL_MATRIX>
 ScalarType diff(ublas::compressed_matrix<ScalarType> & cpu_matrix, VCL_MATRIX & gpu_matrix)
 {
   typedef ublas::compressed_matrix<ScalarType>  CPU_MATRIX;
@@ -168,7 +175,7 @@ ScalarType diff(ublas::compressed_matrix<ScalarType> & cpu_matrix, VCL_MATRIX &
 }
 
 
-template <typename NumericT, typename VCL_MatrixT, typename Epsilon, typename UblasVectorT, typename VCLVectorT>
+template<typename NumericT, typename VCL_MatrixT, typename Epsilon, typename UblasVectorT, typename VCLVectorT>
 int strided_matrix_vector_product_test(Epsilon epsilon,
                                         UblasVectorT & result, UblasVectorT const & rhs,
                                         VCLVectorT & vcl_result, VCLVectorT & vcl_rhs)
@@ -192,7 +199,7 @@ int strided_matrix_vector_product_test(Epsilon epsilon,
     vec(3) = rhs(9);
     viennacl::project(vcl_result, viennacl::slice(1, 3, 5)) = viennacl::linalg::prod(vcl_sparse_matrix2, viennacl::project(vcl_rhs, viennacl::slice(3, 2, 4)));
 
-    if( std::fabs(diff(result, vcl_result)) > epsilon )
+    if ( std::fabs(diff(result, vcl_result)) > epsilon )
     {
       std::cout << "# Error at operation: matrix-vector product with stided vectors, part 1" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -206,7 +213,7 @@ int strided_matrix_vector_product_test(Epsilon epsilon,
 
     viennacl::project(vcl_result, viennacl::slice(1, 3, 5)) = viennacl::linalg::prod(vcl_sparse_matrix2, vec);
 
-    if( std::fabs(diff(result, vcl_result)) > epsilon )
+    if ( std::fabs(diff(result, vcl_result)) > epsilon )
     {
       std::cout << "# Error at operation: matrix-vector product with strided vectors, part 2" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -236,7 +243,7 @@ int resize_test(Epsilon const& epsilon)
    viennacl::copy(vcl_matrix, other_matrix);
 
    std::cout << "Checking for equality after copy..." << std::endl;
-    if( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
+    if ( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
     {
         std::cout << "# Error at operation: equality after copy with sparse matrix" << std::endl;
         std::cout << "  diff: " << std::fabs(diff(ublas_matrix, vcl_matrix)) << std::endl;
@@ -254,7 +261,7 @@ int resize_test(Epsilon const& epsilon)
 
    vcl_matrix.resize(10, 10, true);
 
-    if( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
+    if ( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
     {
         std::cout << "# Error at operation: resize (to larger) with sparse matrix" << std::endl;
         std::cout << "  diff: " << std::fabs(diff(ublas_matrix, vcl_matrix)) << std::endl;
@@ -281,7 +288,7 @@ int resize_test(Epsilon const& epsilon)
    vcl_matrix.resize(7, 7);
 
    //std::cout << ublas_matrix << std::endl;
-    if( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
+    if ( std::fabs(diff(ublas_matrix, vcl_matrix)) > epsilon )
     {
         std::cout << "# Error at operation: resize (to smaller) with sparse matrix" << std::endl;
         std::cout << "  diff: " << std::fabs(diff(ublas_matrix, vcl_matrix)) << std::endl;
@@ -386,6 +393,8 @@ int resize_test(Epsilon const& epsilon)
 template< typename NumericT, typename Epsilon >
 int test(Epsilon const& epsilon)
 {
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   std::cout << "Testing resizing of compressed_matrix..." << std::endl;
   int retval = resize_test<NumericT, viennacl::compressed_matrix<NumericT> >(epsilon);
   if (retval != EXIT_SUCCESS)
@@ -401,11 +410,12 @@ int test(Epsilon const& epsilon)
   ublas::vector<NumericT> result;
   ublas::compressed_matrix<NumericT> ublas_matrix;
 
-  if (viennacl::io::read_matrix_market_file(ublas_matrix, "../../examples/testdata/mat65k.mtx") == EXIT_FAILURE)
+  if (viennacl::io::read_matrix_market_file(ublas_matrix, "../examples/testdata/mat65k.mtx") == EXIT_FAILURE)
   {
     std::cout << "Error reading Matrix file" << std::endl;
     return EXIT_FAILURE;
   }
+
   //unsigned int cg_mat_size = cg_mat.size();
   std::cout << "done reading matrix" << std::endl;
 
@@ -414,7 +424,7 @@ int test(Epsilon const& epsilon)
   for (std::size_t i=0; i<rhs.size(); ++i)
   {
     ublas_matrix(i,i) = NumericT(0.5);   // Get rid of round-off errors by making row-sums unequal to zero:
-    rhs[i] = NumericT(1) + random<NumericT>();
+    rhs[i] = NumericT(1) + randomNumber();
   }
 
   // add some random numbers to the double-compressed matrix:
@@ -442,6 +452,7 @@ int test(Epsilon const& epsilon)
   viennacl::compressed_compressed_matrix<NumericT> vcl_compressed_compressed_matrix(rhs.size(), rhs.size());
   viennacl::coordinate_matrix<NumericT> vcl_coordinate_matrix(rhs.size(), rhs.size());
   viennacl::ell_matrix<NumericT> vcl_ell_matrix;
+  viennacl::sliced_ell_matrix<NumericT> vcl_sliced_ell_matrix;
   viennacl::hyb_matrix<NumericT> vcl_hyb_matrix;
 
   viennacl::copy(rhs.begin(), rhs.end(), vcl_rhs.begin());
@@ -456,7 +467,7 @@ int test(Epsilon const& epsilon)
   std::cout << "Testing products: compressed_matrix" << std::endl;
   vcl_result = viennacl::linalg::prod(vcl_compressed_matrix, vcl_rhs);
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -493,7 +504,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix_trans), result, boost::numeric::ublas::unit_upper_tag());
   viennacl::linalg::inplace_solve(vcl_compressed_matrix, vcl_result, viennacl::linalg::unit_upper_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: unit upper triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -506,7 +517,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix_trans), result, boost::numeric::ublas::upper_tag());
   viennacl::linalg::inplace_solve(vcl_compressed_matrix, vcl_result, viennacl::linalg::upper_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: upper triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -547,7 +558,7 @@ int test(Epsilon const& epsilon)
                                                     multifrontal_L_row_elimination_num_list_);*/
 
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: unit lower triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -586,7 +597,7 @@ int test(Epsilon const& epsilon)
                                                     multifrontal_U_row_elimination_num_list_);*/
 
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: lower triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -600,7 +611,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(ublas_matrix, result, boost::numeric::ublas::lower_tag());
   viennacl::linalg::inplace_solve(vcl_compressed_matrix, vcl_result, viennacl::linalg::lower_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: lower triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -617,7 +628,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix), result, boost::numeric::ublas::unit_upper_tag());
   viennacl::linalg::inplace_solve(trans(vcl_compressed_matrix), vcl_result, viennacl::linalg::unit_upper_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: unit upper triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -630,7 +641,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix), result, boost::numeric::ublas::upper_tag());
   viennacl::linalg::inplace_solve(trans(vcl_compressed_matrix), vcl_result, viennacl::linalg::upper_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: upper triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -644,7 +655,7 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix), result, boost::numeric::ublas::unit_lower_tag());
   viennacl::linalg::inplace_solve(trans(vcl_compressed_matrix), vcl_result, viennacl::linalg::unit_lower_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: unit lower triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -657,19 +668,18 @@ int test(Epsilon const& epsilon)
   boost::numeric::ublas::inplace_solve(trans(ublas_matrix), result, boost::numeric::ublas::lower_tag());
   viennacl::linalg::inplace_solve(trans(vcl_compressed_matrix), vcl_result, viennacl::linalg::lower_tag());
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: lower triangular solve with compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
     retval = EXIT_FAILURE;
   }
 
-
   std::cout << "Testing products: compressed_compressed_matrix" << std::endl;
   result     = viennacl::linalg::prod(ublas_cc_matrix, rhs);
   vcl_result = viennacl::linalg::prod(vcl_compressed_compressed_matrix, vcl_rhs);
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product with compressed_compressed_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -683,7 +693,7 @@ int test(Epsilon const& epsilon)
     // check that entries are correct by computing the product again:
     result     = viennacl::linalg::prod(temp, rhs);
 
-    if( std::fabs(diff(result, vcl_result)) > epsilon )
+    if ( std::fabs(diff(result, vcl_result)) > epsilon )
     {
       std::cout << "# Error at operation: matrix-vector product with compressed_compressed_matrix (after copy back)" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -699,7 +709,7 @@ int test(Epsilon const& epsilon)
   result     = viennacl::linalg::prod(ublas_matrix, rhs);
   vcl_result = viennacl::linalg::prod(vcl_coordinate_matrix, vcl_rhs);
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product with coordinate_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -728,7 +738,7 @@ int test(Epsilon const& epsilon)
   //std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
   //std::cout << "First entry of result vector: " << vcl_result[0] << std::endl;
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product with ell_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -740,6 +750,29 @@ int test(Epsilon const& epsilon)
   if (retval != EXIT_SUCCESS)
     return retval;
 
+  //std::cout << "Copying sliced_ell_matrix" << std::endl;
+  viennacl::copy(ublas_matrix, vcl_sliced_ell_matrix);
+  //ublas_matrix.clear();
+  //viennacl::copy(vcl_hyb_matrix, ublas_matrix);// just to check that it's works
+  //viennacl::copy(ublas_matrix, vcl_hyb_matrix);
+
+  std::cout << "Testing products: sliced_ell_matrix" << std::endl;
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result.clear();
+  vcl_result = viennacl::linalg::prod(vcl_sliced_ell_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with sliced_ell_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products: sliced_ell_matrix, strided vectors" << std::endl;
+  retval = strided_matrix_vector_product_test<NumericT, viennacl::sliced_ell_matrix<NumericT> >(epsilon, result, rhs, vcl_result, vcl_rhs);
+  if (retval != EXIT_SUCCESS)
+    return retval;
+
 
   //std::cout << "Copying hyb_matrix" << std::endl;
   viennacl::copy(ublas_matrix, vcl_hyb_matrix);
@@ -756,7 +789,7 @@ int test(Epsilon const& epsilon)
   //std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
   //std::cout << "First entry of result vector: " << vcl_result[0] << std::endl;
 
-  if( std::fabs(diff(result, vcl_result)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product with hyb_matrix" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
@@ -781,7 +814,7 @@ int test(Epsilon const& epsilon)
   result     = alpha * viennacl::linalg::prod(ublas_matrix, rhs) + beta * result;
   vcl_result2 = alpha * viennacl::linalg::prod(vcl_compressed_matrix, vcl_rhs) + beta * vcl_result;
 
-  if( std::fabs(diff(result, vcl_result2)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result2)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product (compressed_matrix) with scaled additions" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result2)) << std::endl;
@@ -792,7 +825,7 @@ int test(Epsilon const& epsilon)
   vcl_result2.clear();
   vcl_result2 = alpha * viennacl::linalg::prod(vcl_coordinate_matrix, vcl_rhs) + beta * vcl_result;
 
-  if( std::fabs(diff(result, vcl_result2)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result2)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product (coordinate_matrix) with scaled additions" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result2)) << std::endl;
@@ -802,7 +835,7 @@ int test(Epsilon const& epsilon)
   vcl_result2.clear();
   vcl_result2 = alpha * viennacl::linalg::prod(vcl_ell_matrix, vcl_rhs) + beta * vcl_result;
 
-  if( std::fabs(diff(result, vcl_result2)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result2)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product (ell_matrix) with scaled additions" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result2)) << std::endl;
@@ -812,13 +845,94 @@ int test(Epsilon const& epsilon)
   vcl_result2.clear();
   vcl_result2 = alpha * viennacl::linalg::prod(vcl_hyb_matrix, vcl_rhs) + beta * vcl_result;
 
-  if( std::fabs(diff(result, vcl_result2)) > epsilon )
+  if ( std::fabs(diff(result, vcl_result2)) > epsilon )
   {
     std::cout << "# Error at operation: matrix-vector product (hyb_matrix) with scaled additions" << std::endl;
     std::cout << "  diff: " << std::fabs(diff(result, vcl_result2)) << std::endl;
     retval = EXIT_FAILURE;
   }
 
+  ////////////// Test of .clear() ////////////////
+  ublas_matrix.clear();
+
+  std::cout << "Testing products after clear(): compressed_matrix" << std::endl;
+  vcl_compressed_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_compressed_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with compressed_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products after clear(): compressed_compressed_matrix" << std::endl;
+  vcl_compressed_compressed_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_compressed_compressed_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with compressed_compressed_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products after clear(): coordinate_matrix" << std::endl;
+  vcl_coordinate_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_coordinate_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with coordinate_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products after clear(): ell_matrix" << std::endl;
+  vcl_ell_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_ell_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with ell_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products after clear(): hyb_matrix" << std::endl;
+  vcl_hyb_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_hyb_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with hyb_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
+  std::cout << "Testing products after clear(): sliced_ell_matrix" << std::endl;
+  vcl_sliced_ell_matrix.clear();
+  result     = ublas::scalar_vector<NumericT>(result.size(), NumericT(1));
+  result     = viennacl::linalg::prod(ublas_matrix, rhs);
+  vcl_result = viennacl::linalg::prod(vcl_sliced_ell_matrix, vcl_rhs);
+
+  if ( std::fabs(diff(result, vcl_result)) > epsilon )
+  {
+    std::cout << "# Error at operation: matrix-vector product with sliced_ell_matrix" << std::endl;
+    std::cout << "  diff: " << std::fabs(diff(result, vcl_result)) << std::endl;
+    retval = EXIT_FAILURE;
+  }
+
 
   // --------------------------------------------------------------------------
   return retval;
@@ -848,7 +962,7 @@ int main()
     std::cout << "  eps:     " << epsilon << std::endl;
     std::cout << "  numeric: float" << std::endl;
     retval = test<NumericT>(epsilon);
-    if( retval == EXIT_SUCCESS )
+    if ( retval == EXIT_SUCCESS )
         std::cout << "# Test passed" << std::endl;
     else
         return retval;
@@ -858,7 +972,7 @@ int main()
   std::cout << std::endl;
 
 #ifdef VIENNACL_WITH_OPENCL
-  if( viennacl::ocl::current_device().double_support() )
+  if ( viennacl::ocl::current_device().double_support() )
 #endif
   {
     {
@@ -868,7 +982,7 @@ int main()
       std::cout << "  eps:     " << epsilon << std::endl;
       std::cout << "  numeric: double" << std::endl;
       retval = test<NumericT>(epsilon);
-      if( retval == EXIT_SUCCESS )
+      if ( retval == EXIT_SUCCESS )
         std::cout << "# Test passed" << std::endl;
       else
         return retval;
