@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -39,8 +39,9 @@
 #include "viennacl/linalg/norm_2.hpp"
 #include "viennacl/linalg/norm_inf.hpp"
 #include "viennacl/linalg/maxmin.hpp"
+#include "viennacl/linalg/sum.hpp"
 
-#include "Random.hpp"
+#include "viennacl/tools/random.hpp"
 
 
 template<typename NumericT>
@@ -168,8 +169,10 @@ int test(Epsilon const& epsilon,
 {
   int retval = EXIT_SUCCESS;
 
-  NumericT                    cpu_result = 42.0;
-  viennacl::scalar<NumericT>  gpu_result = 43.0;
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
+  NumericT                    cpu_result = NumericT(42.0);
+  viennacl::scalar<NumericT>  gpu_result = NumericT(43.0);
 
   //
   // Initializer:
@@ -205,8 +208,8 @@ int test(Epsilon const& epsilon,
 
   for (std::size_t i=0; i<host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
-    host_v2[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
+    host_v2[i] = NumericT(1.0) + randomNumber();
   }
 
   proxy_copy(host_v1, vcl_v1);  //resync
@@ -230,6 +233,9 @@ int test(Epsilon const& epsilon,
   NumericT cpu_result2 = viennacl::linalg::inner_prod(vcl_v1, vcl_v2);
   gpu_result = viennacl::linalg::inner_prod(vcl_v1, vcl_v2);
 
+  std::cout << "Reference: " << cpu_result << std::endl;
+  std::cout << cpu_result2 << std::endl;
+  std::cout << gpu_result << std::endl;
   if (check(cpu_result, cpu_result2, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
   if (check(cpu_result, gpu_result, epsilon) != EXIT_SUCCESS)
@@ -241,6 +247,9 @@ int test(Epsilon const& epsilon,
   NumericT cpu_result3 = viennacl::linalg::inner_prod(vcl_v1 + vcl_v2, vcl_v2 - vcl_v1);
   gpu_result = viennacl::linalg::inner_prod(vcl_v1 + vcl_v2, vcl_v2 - vcl_v1);
 
+  std::cout << "Reference: " << cpu_result << std::endl;
+  std::cout << cpu_result3 << std::endl;
+  std::cout << gpu_result << std::endl;
   if (check(cpu_result, cpu_result3, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
   if (check(cpu_result, gpu_result, epsilon) != EXIT_SUCCESS)
@@ -438,6 +447,29 @@ int test(Epsilon const& epsilon,
   if (check(cpu_result, gpu_result, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
+  // --------------------------------------------------------------------------
+  std::cout << "Testing sum..." << std::endl;
+  cpu_result = 0;
+  for (std::size_t i=0; i<host_v1.size(); ++i)
+    cpu_result += host_v1[i];
+  cpu_result2 = viennacl::linalg::sum(vcl_v1);
+  gpu_result = viennacl::linalg::sum(vcl_v1);
+
+  if (check(cpu_result, cpu_result2, epsilon) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+  if (check(cpu_result, gpu_result, epsilon) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+
+  cpu_result = 0;
+  for (std::size_t i=0; i<host_v1.size(); ++i)
+    cpu_result += host_v1[i] + host_v2[i];
+  cpu_result3 = viennacl::linalg::sum(vcl_v1 + vcl_v2);
+  gpu_result = viennacl::linalg::sum(vcl_v1 + vcl_v2);
+
+  if (check(cpu_result, cpu_result3, epsilon) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
+  if (check(cpu_result, gpu_result, epsilon) != EXIT_SUCCESS)
+    return EXIT_FAILURE;
 
 
   //
@@ -491,7 +523,7 @@ int test(Epsilon const& epsilon,
   //
   for (std::size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);  //resync
@@ -502,21 +534,21 @@ int test(Epsilon const& epsilon,
   viennacl::scalar<NumericT> gpu_alpha = alpha;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i]  *= long(alpha);
+    host_v1[i]  *= NumericT(long(alpha));
   vcl_v1    *= long(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i]  *= float(alpha);
+    host_v1[i]  *= NumericT(float(alpha));
   vcl_v1    *= float(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i]  *= double(alpha);
+    host_v1[i]  *= NumericT(double(alpha));
   vcl_v1    *= double(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -547,21 +579,21 @@ int test(Epsilon const& epsilon,
 
   std::cout << "Testing shrinking with CPU scalar..." << std::endl;
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] /= long(beta);
+    host_v1[i] /= NumericT(long(beta));
   vcl_v1   /= long(beta);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] /= float(beta);
+    host_v1[i] /= NumericT(float(beta));
   vcl_v1   /= float(beta);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] /= double(beta);
+    host_v1[i] /= NumericT(double(beta));
   vcl_v1   /= double(beta);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -583,7 +615,7 @@ int test(Epsilon const& epsilon,
   //
   for (size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);  //resync
@@ -661,21 +693,21 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing multiply-add on vector with CPU scalar (right)..." << std::endl;
   for (size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] + host_v2[i] * float(alpha);
+    host_v1[i] = host_v1[i] + host_v2[i] * NumericT(float(alpha));
   vcl_v1   = vcl_v1   +   vcl_v2 * float(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] + host_v2[i] * double(alpha);
+    host_v1[i] = host_v1[i] + host_v2[i] * NumericT(double(alpha));
   vcl_v1   = vcl_v1   +   vcl_v2 * double(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -689,21 +721,21 @@ int test(Epsilon const& epsilon,
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = long(alpha) * host_v1[i] + host_v2[i];
+    host_v1[i] = NumericT(long(alpha)) * host_v1[i] + host_v2[i];
   vcl_v1   = long(alpha) *   vcl_v1 +   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = float(alpha) * host_v1[i] + host_v2[i];
+    host_v1[i] = NumericT(float(alpha)) * host_v1[i] + host_v2[i];
   vcl_v1   = float(alpha) *   vcl_v1 +   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = double(alpha) * host_v1[i] + host_v2[i];
+    host_v1[i] = NumericT(double(alpha)) * host_v1[i] + host_v2[i];
   vcl_v1   = double(alpha) *   vcl_v1 +   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -717,21 +749,21 @@ int test(Epsilon const& epsilon,
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = long(alpha) * host_v1[i] + long(beta) * host_v2[i];
+    host_v1[i] = NumericT(long(alpha)) * host_v1[i] + NumericT(long(beta)) * host_v2[i];
   vcl_v1   = long(alpha) *   vcl_v1 + long(beta) *   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = float(alpha) * host_v1[i] + float(beta) * host_v2[i];
+    host_v1[i] = NumericT(float(alpha)) * host_v1[i] + NumericT(float(beta)) * host_v2[i];
   vcl_v1   = float(alpha) *   vcl_v1 + float(beta) *   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = double(alpha) * host_v1[i] + double(beta) * host_v2[i];
+    host_v1[i] = NumericT(double(alpha)) * host_v1[i] + NumericT(double(beta)) * host_v2[i];
   vcl_v1   = double(alpha) *   vcl_v1 + double(beta) *   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -745,21 +777,21 @@ int test(Epsilon const& epsilon,
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] += host_v2[i] * long(alpha);
+    host_v1[i] += host_v2[i] * NumericT(long(alpha));
   vcl_v1   +=   vcl_v2 * long(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] += host_v2[i] * float(alpha);
+    host_v1[i] += host_v2[i] * NumericT(float(alpha));
   vcl_v1   +=   vcl_v2 * float(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] += double(alpha) * host_v2[i];
+    host_v1[i] += NumericT(double(alpha)) * host_v2[i];
   vcl_v1   += double(alpha) *   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -854,28 +886,28 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing division-add on vector with CPU scalar (right)..." << std::endl;
   for (size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] + host_v2[i] / long(alpha);
+    host_v1[i] = host_v1[i] + host_v2[i] / NumericT(long(alpha));
   vcl_v1   = vcl_v1   + vcl_v2 / long(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] + host_v2[i] / float(alpha);
+    host_v1[i] = host_v1[i] + host_v2[i] / NumericT(float(alpha));
   vcl_v1   = vcl_v1   + vcl_v2 / float(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] + host_v2[i] / double(alpha);
+    host_v1[i] = host_v1[i] + host_v2[i] / NumericT(double(alpha));
   vcl_v1   = vcl_v1   + vcl_v2 / double(alpha);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -889,14 +921,14 @@ int test(Epsilon const& epsilon,
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] / float(alpha) + host_v2[i];
+    host_v1[i] = host_v1[i] / NumericT(float(alpha)) + host_v2[i];
   vcl_v1   =   vcl_v1 / float(alpha) +   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] / double(alpha) + host_v2[i];
+    host_v1[i] = host_v1[i] / NumericT(double(alpha)) + host_v2[i];
   vcl_v1   =   vcl_v1 / double(alpha) +   vcl_v2;
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -910,14 +942,14 @@ int test(Epsilon const& epsilon,
   proxy_copy(host_v2, vcl_v2);
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] / float(alpha) + host_v2[i] / float(beta);
+    host_v1[i] = host_v1[i] / NumericT(float(alpha)) + host_v2[i] / NumericT(float(beta));
   vcl_v1   =   vcl_v1 / float(alpha) +   vcl_v2 / float(beta);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
     return EXIT_FAILURE;
 
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = host_v1[i] / double(alpha) + host_v2[i] / double(beta);
+    host_v1[i] = host_v1[i] / NumericT(double(alpha)) + host_v2[i] / NumericT(double(beta));
   vcl_v1   =   vcl_v1 / double(alpha) +   vcl_v2 / double(beta);
 
   if (check(host_v1, vcl_v1, epsilon) != EXIT_SUCCESS)
@@ -1081,7 +1113,7 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing multiply-subtract on vector with CPU scalar (right)..." << std::endl;
   for (size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);
@@ -1223,7 +1255,7 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing division-subtract on vector with CPU scalar (right)..." << std::endl;
   for (size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);
@@ -1455,7 +1487,7 @@ int test(Epsilon const& epsilon,
   //
   for (std::size_t i=0; i < host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
     host_v2[i] = NumericT(3.1415) * host_v1[i];
   }
   proxy_copy(host_v1, vcl_v1);
@@ -1512,8 +1544,8 @@ int test(Epsilon const& epsilon,
   // --------------------------------------------------------------------------
   for (std::size_t i=0; i<host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
-    host_v2[i] = NumericT(5.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
+    host_v2[i] = NumericT(5.0) + randomNumber();
   }
 
   proxy_copy(host_v1, vcl_v1);
@@ -1632,8 +1664,8 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing elementwise division..." << std::endl;
   for (std::size_t i=0; i<host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.0) + random<NumericT>();
-    host_v2[i] = NumericT(5.0) + random<NumericT>();
+    host_v1[i] = NumericT(1.0) + randomNumber();
+    host_v2[i] = NumericT(5.0) + randomNumber();
   }
 
   proxy_copy(host_v1, vcl_v1);
@@ -1730,8 +1762,8 @@ int test(Epsilon const& epsilon,
   std::cout << "Testing elementwise power function..." << std::endl;
   for (std::size_t i=0; i<host_v1.size(); ++i)
   {
-    host_v1[i] = NumericT(1.1) + NumericT(0.5) * random<NumericT>();
-    host_v2[i] = NumericT(1.1) + NumericT(0.5) * random<NumericT>();
+    host_v1[i] = NumericT(1.1) + NumericT(0.5) * randomNumber();
+    host_v2[i] = NumericT(1.1) + NumericT(0.5) * randomNumber();
   }
   std::vector<NumericT> std_v3(host_v1.size());
   vector_proxy<NumericT> host_v3(&std_v3[0], 0, 1, host_v1.size());
@@ -1897,7 +1929,7 @@ int test(Epsilon const& epsilon,
 
   std::cout << "Testing unary elementwise operations..." << std::endl;
   for (size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = random<NumericT>() / NumericT(4);
+    host_v1[i] = randomNumber() / NumericT(4);
 
 #define GENERATE_UNARY_OP_TEST(FUNCNAME) \
   for (std::size_t i=0; i<host_v1.size(); ++i) \
@@ -1968,7 +2000,7 @@ int test(Epsilon const& epsilon,
   GENERATE_UNARY_OP_TEST(cos);
   GENERATE_UNARY_OP_TEST(cosh);
   for (std::size_t i=0; i < host_v1.size(); ++i)
-    host_v1[i] = random<NumericT>() / NumericT(4);
+    host_v1[i] = randomNumber() / NumericT(4);
   GENERATE_UNARY_OP_TEST(exp);
   GENERATE_UNARY_OP_TEST(floor);
   GENERATE_UNARY_OP_TEST(fabs);
@@ -2034,6 +2066,8 @@ int test(Epsilon const& epsilon)
   int retval = EXIT_SUCCESS;
   std::size_t size = 24656;
 
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   std::cout << "Running tests for vector of size " << size << std::endl;
 
   //
@@ -2044,8 +2078,8 @@ int test(Epsilon const& epsilon)
 
   for (std::size_t i=0; i<std_full_vec.size(); ++i)
   {
-    std_full_vec[i]  = NumericT(1.0) + random<NumericT>();
-    std_full_vec2[i] = NumericT(1.0) + random<NumericT>();
+    std_full_vec[i]  = NumericT(1.0) + randomNumber();
+    std_full_vec2[i] = NumericT(1.0) + randomNumber();
   }
 
   std::size_t r1_start = std_full_vec.size() / 4;
