@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -15,6 +15,12 @@
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
 
+
+
+/** \file tests/src/vector_multi_inner_prod.cpp  Tests the performance of multiple inner products with a common vector.
+*   \test   Tests the performance of multiple inner products with a common vector.
+**/
+
 //
 // *** System
 //
@@ -39,8 +45,7 @@
 #include "viennacl/linalg/norm_1.hpp"
 #include "viennacl/linalg/norm_2.hpp"
 #include "viennacl/linalg/norm_inf.hpp"
-
-#include "Random.hpp"
+#include "viennacl/tools/random.hpp"
 
 using namespace boost::numeric;
 
@@ -48,7 +53,7 @@ using namespace boost::numeric;
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, ScalarType const & s2)
 {
    viennacl::backend::finish();
@@ -59,7 +64,7 @@ ScalarType diff(ScalarType const & s1, ScalarType const & s2)
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, viennacl::scalar<ScalarType> const & s2)
 {
    viennacl::backend::finish();
@@ -70,7 +75,7 @@ ScalarType diff(ScalarType const & s1, viennacl::scalar<ScalarType> const & s2)
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType const & s1, viennacl::entry_proxy<ScalarType> const & s2)
 {
    viennacl::backend::finish();
@@ -81,7 +86,7 @@ ScalarType diff(ScalarType const & s1, viennacl::entry_proxy<ScalarType> const &
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType, typename ViennaCLVectorType>
+template<typename ScalarType, typename ViennaCLVectorType>
 ScalarType diff(ublas::vector<ScalarType> const & v1, ViennaCLVectorType const & vcl_vec)
 {
    ublas::vector<ScalarType> v2_cpu(vcl_vec.size());
@@ -99,7 +104,7 @@ ScalarType diff(ublas::vector<ScalarType> const & v1, ViennaCLVectorType const &
    return ublas::norm_inf(v2_cpu);
 }
 
-template <typename ScalarType, typename ViennaCLVectorType>
+template<typename ScalarType, typename ViennaCLVectorType>
 ScalarType diff(ublas::vector_slice<ublas::vector<ScalarType> > const & v1, ViennaCLVectorType const & vcl_vec)
 {
    ublas::vector<ScalarType> v2_cpu(vcl_vec.size());
@@ -118,7 +123,7 @@ ScalarType diff(ublas::vector_slice<ublas::vector<ScalarType> > const & v1, Vien
 }
 
 
-template <typename T1, typename T2>
+template<typename T1, typename T2>
 int check(T1 const & t1, T2 const & t2, double epsilon)
 {
   int retval = EXIT_SUCCESS;
@@ -145,12 +150,14 @@ int test(Epsilon const& epsilon,
 {
   int retval = EXIT_SUCCESS;
 
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   for (std::size_t i=0; i<ublas_v1.size(); ++i)
   {
-    ublas_v1[i] = NumericT(1.0) + random<NumericT>();
-    ublas_v2[i] = NumericT(1.0) + random<NumericT>();
-    ublas_v3[i] = NumericT(1.0) + random<NumericT>();
-    ublas_v4[i] = NumericT(1.0) + random<NumericT>();
+    ublas_v1[i] = NumericT(1.0) + randomNumber();
+    ublas_v2[i] = NumericT(1.0) + randomNumber();
+    ublas_v3[i] = NumericT(1.0) + randomNumber();
+    ublas_v4[i] = NumericT(1.0) + randomNumber();
   }
 
   viennacl::copy(ublas_v1.begin(), ublas_v1.end(), vcl_v1.begin());  //resync
@@ -331,6 +338,8 @@ int test(Epsilon const& epsilon,
 template< typename NumericT, typename Epsilon >
 int test(Epsilon const& epsilon)
 {
+  viennacl::tools::uniform_random_numbers<NumericT> randomNumber;
+
   int retval = EXIT_SUCCESS;
   std::size_t size = 8 * 1337;
 
@@ -344,8 +353,8 @@ int test(Epsilon const& epsilon)
 
   for (std::size_t i=0; i<ublas_full_vec1.size(); ++i)
   {
-    ublas_full_vec1[i]  = NumericT(1.0) + random<NumericT>();
-    ublas_full_vec2[i] = NumericT(1.0) + random<NumericT>();
+    ublas_full_vec1[i] = NumericT(1.0) + randomNumber();
+    ublas_full_vec2[i] = NumericT(1.0) + randomNumber();
   }
 
   ublas::slice s1(    ublas_full_vec1.size() / 8, 3, ublas_full_vec1.size() / 8);
@@ -546,7 +555,7 @@ int main()
       std::cout << "  eps:     " << epsilon << std::endl;
       std::cout << "  numeric: float" << std::endl;
       retval = test<NumericT>(epsilon);
-      if( retval == EXIT_SUCCESS )
+      if ( retval == EXIT_SUCCESS )
          std::cout << "# Test passed" << std::endl;
       else
          return retval;
@@ -555,7 +564,7 @@ int main()
    std::cout << "----------------------------------------------" << std::endl;
    std::cout << std::endl;
 #ifdef VIENNACL_WITH_OPENCL
-   if( viennacl::ocl::current_device().double_support() )
+   if ( viennacl::ocl::current_device().double_support() )
 #endif
    {
       {
@@ -565,7 +574,7 @@ int main()
          std::cout << "  eps:     " << epsilon << std::endl;
          std::cout << "  numeric: double" << std::endl;
          retval = test<NumericT>(epsilon);
-         if( retval == EXIT_SUCCESS )
+         if ( retval == EXIT_SUCCESS )
            std::cout << "# Test passed" << std::endl;
          else
            return retval;
