@@ -2,7 +2,7 @@
 #define VIENNACL_OCL_CONTEXT_HPP_
 
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2015, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -13,7 +13,7 @@
 
    Project Head:    Karl Rupp                   rupp@iue.tuwien.ac.at
 
-   (A list of authors and contributors can be found in the PDF manual)
+   (A list of authors and contributors can be found in the manual)
 
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
@@ -34,6 +34,7 @@
 #include <map>
 #include <cstdlib>
 #include "viennacl/ocl/forwards.h"
+#include "viennacl/ocl/error.hpp"
 #include "viennacl/ocl/handle.hpp"
 #include "viennacl/ocl/kernel.hpp"
 #include "viennacl/ocl/program.hpp"
@@ -290,10 +291,7 @@ public:
       return (it->second)[current_queue_id_];
     }
 
-    std::cerr << "ViennaCL: FATAL ERROR: Could not obtain current command queue!" << std::endl;
-    std::cout << "Number of queues in context: " << queues_.size() << std::endl;
-    std::cout << "Number of devices in context: " << devices_.size() << std::endl;
-    throw "queue not found!";
+    throw queue_not_found("Could not obtain current command queue");
 
     //return ((*it)->second)[current_queue_id_];
   }
@@ -412,11 +410,11 @@ public:
 
         cached.read((char*)&len, sizeof(vcl_size_t));
         buffer.resize(len);
-        cached.read((char*)buffer.data(), std::streamsize(len));
+        cached.read((char*)(&buffer[0]), std::streamsize(len));
 
         cl_int status;
         cl_device_id devid = devices_[0].id();
-        const unsigned char * bufdata = buffer.data();
+        const unsigned char * bufdata = &buffer[0];
         temp = clCreateProgramWithBinary(h_.get(),1,&devid,&len, &bufdata,&status,&err);
         VIENNACL_ERR_CHECK(err);
       }
@@ -460,14 +458,14 @@ public:
 
       std::vector<vcl_size_t> sizes(devices_.size());
       clGetProgramInfo(temp,CL_PROGRAM_BINARY_SIZES,0,NULL,&len);
-      clGetProgramInfo(temp,CL_PROGRAM_BINARY_SIZES,len,(void*)sizes.data(),NULL);
+      clGetProgramInfo(temp,CL_PROGRAM_BINARY_SIZES,len,(void*)&sizes[0],NULL);
 
       std::vector<unsigned char*> binaries;
       for (vcl_size_t i = 0; i < devices_.size(); ++i)
         binaries.push_back(new unsigned char[sizes[i]]);
 
       clGetProgramInfo(temp,CL_PROGRAM_BINARIES,0,NULL,&len);
-      clGetProgramInfo(temp,CL_PROGRAM_BINARIES,len,binaries.data(),NULL);
+      clGetProgramInfo(temp,CL_PROGRAM_BINARIES,len,&binaries[0],NULL);
 
       std::string prefix;
       for(std::vector< viennacl::ocl::device >::const_iterator it = devices_.begin(); it != devices_.end(); ++it)
@@ -546,7 +544,7 @@ public:
         return **it;
     }
     std::cerr << "ViennaCL: Could not find program '" << name << "'" << std::endl;
-    throw "In class 'context': name invalid in get_program()";
+    throw program_not_found(name);
     //return programs_[0];  //return a defined object
   }
 
@@ -565,7 +563,7 @@ public:
         return **it;
     }
     std::cerr << "ViennaCL: Could not find program '" << name << "'" << std::endl;
-    throw "In class 'context': name invalid in get_program()";
+    throw program_not_found(name);
     //return programs_[0];  //return a defined object
   }
 
@@ -784,7 +782,7 @@ inline viennacl::ocl::kernel & viennacl::ocl::program::get_kernel(std::string co
   }
   std::cerr << "ViennaCL: FATAL ERROR: Could not find kernel '" << name << "' from program '" << name_ << "'" << std::endl;
   std::cout << "Number of kernels in program: " << kernels_.size() << std::endl;
-  throw "Kernel not found";
+  throw kernel_not_found("Kernel not found");
   //return kernels_[0];  //return a defined object
 }
 
